function Get-SecurityBaseline {
    <#
    .SYNOPSIS
    Get security baseline elements based on a given category of tests.

    Author: @itm4n
    License: BSD 3-Clause
    
    .PARAMETER Category
    Category determines the type of rule to check. ComputerConfig: HKLM, UserConfig: HKCU, SecurityTemplate: ?, AuditSubcategory: audit policy, CSE-Machine: Machine Client-Side Extension, User Client-Side Extension. 
    
    .PARAMETER Role
    Optional parameter that defines the machine's profile: Workstation, Server or Domain Controller. If not specified, it is automatically determined.

    .NOTES
    Get unique policy names from *.PolicyRules files:

        PS C:\Policies> $xml.GetElementsByTagName("PolicyName") | Select-Object InnerText -unique

        InnerText
        ---------
        MSFT Windows Server 2004 - Domain Controller Virtualization Based Security
        MSFT Windows Server 2004 - Domain Controller
        MSFT Windows 10 2004 - BitLocker
        MSFT Windows 10 2004 and Server 2004 - Defender Antivirus
        MSFT Internet Explorer 11 - User
        MSFT Windows 10 2004 and Server 2004 Member Server - Credential Guard
        MSFT Windows Server 2004 - Member Server
        MSFT Windows 10 2004 - User
        MSFT Windows 10 2004 - Computer
        MSFT Internet Explorer 11 - Computer
        MSFT Windows 10 2004 and Server 2004 - Domain Security
    #>

    [CmdletBinding()] Param(
        [Parameter(Mandatory=$true)]
        [ValidateSet("ComputerConfig", "UserConfig", "SecurityTemplate", "AuditSubcategory", "CSE-Machine", "CSE-User")]
        [string]
        $Category,

        [ValidateSet("Windows10", "Windows11", "Office", "Edge")]
        [string]
        $BaselineProfile
    )

    $Windows10Profile = @"
<PolicyRules>
<ComputerConfig><Key>Software\Microsoft\Windows\CurrentVersion\Policies\Ext</Key><Value>RunThisTimeEnabled</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Microsoft\Windows\CurrentVersion\Policies\Ext</Key><Value>VersionCheckEnabled</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Internet Explorer\Download</Key><Value>RunInvalidSignatures</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Internet Explorer\Download</Key><Value>CheckExeSignatures</Value><RegType>REG_SZ</RegType><RegData>yes</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Internet Explorer\Main</Key><Value>Isolation64Bit</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Internet Explorer\Main</Key><Value>DisableEPMCompat</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Internet Explorer\Main</Key><Value>Isolation</Value><RegType>REG_SZ</RegType><RegData>PMEM</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Internet Explorer\Main\FeatureControl\FEATURE_DISABLE_MK_PROTOCOL</Key><Value>(Reserved)</Value><RegType>REG_SZ</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Internet Explorer\Main\FeatureControl\FEATURE_DISABLE_MK_PROTOCOL</Key><Value>iexplore.exe</Value><RegType>REG_SZ</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Internet Explorer\Main\FeatureControl\FEATURE_DISABLE_MK_PROTOCOL</Key><Value>explorer.exe</Value><RegType>REG_SZ</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Internet Explorer\Main\FeatureControl\FEATURE_MIME_HANDLING</Key><Value>explorer.exe</Value><RegType>REG_SZ</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Internet Explorer\Main\FeatureControl\FEATURE_MIME_HANDLING</Key><Value>iexplore.exe</Value><RegType>REG_SZ</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Internet Explorer\Main\FeatureControl\FEATURE_MIME_HANDLING</Key><Value>(Reserved)</Value><RegType>REG_SZ</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Internet Explorer\Main\FeatureControl\FEATURE_MIME_SNIFFING</Key><Value>explorer.exe</Value><RegType>REG_SZ</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Internet Explorer\Main\FeatureControl\FEATURE_MIME_SNIFFING</Key><Value>iexplore.exe</Value><RegType>REG_SZ</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Internet Explorer\Main\FeatureControl\FEATURE_MIME_SNIFFING</Key><Value>(Reserved)</Value><RegType>REG_SZ</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Internet Explorer\Main\FeatureControl\FEATURE_RESTRICT_ACTIVEXINSTALL</Key><Value>(Reserved)</Value><RegType>REG_SZ</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Internet Explorer\Main\FeatureControl\FEATURE_RESTRICT_ACTIVEXINSTALL</Key><Value>explorer.exe</Value><RegType>REG_SZ</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Internet Explorer\Main\FeatureControl\FEATURE_RESTRICT_ACTIVEXINSTALL</Key><Value>iexplore.exe</Value><RegType>REG_SZ</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Internet Explorer\Main\FeatureControl\FEATURE_RESTRICT_FILEDOWNLOAD</Key><Value>(Reserved)</Value><RegType>REG_SZ</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Internet Explorer\Main\FeatureControl\FEATURE_RESTRICT_FILEDOWNLOAD</Key><Value>iexplore.exe</Value><RegType>REG_SZ</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Internet Explorer\Main\FeatureControl\FEATURE_RESTRICT_FILEDOWNLOAD</Key><Value>explorer.exe</Value><RegType>REG_SZ</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Internet Explorer\Main\FeatureControl\FEATURE_SECURITYBAND</Key><Value>(Reserved)</Value><RegType>REG_SZ</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Internet Explorer\Main\FeatureControl\FEATURE_SECURITYBAND</Key><Value>iexplore.exe</Value><RegType>REG_SZ</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Internet Explorer\Main\FeatureControl\FEATURE_SECURITYBAND</Key><Value>explorer.exe</Value><RegType>REG_SZ</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Internet Explorer\Main\FeatureControl\FEATURE_WINDOW_RESTRICTIONS</Key><Value>iexplore.exe</Value><RegType>REG_SZ</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Internet Explorer\Main\FeatureControl\FEATURE_WINDOW_RESTRICTIONS</Key><Value>(Reserved)</Value><RegType>REG_SZ</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Internet Explorer\Main\FeatureControl\FEATURE_WINDOW_RESTRICTIONS</Key><Value>explorer.exe</Value><RegType>REG_SZ</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Internet Explorer\Main\FeatureControl\FEATURE_ZONE_ELEVATION</Key><Value>(Reserved)</Value><RegType>REG_SZ</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Internet Explorer\Main\FeatureControl\FEATURE_ZONE_ELEVATION</Key><Value>explorer.exe</Value><RegType>REG_SZ</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Internet Explorer\Main\FeatureControl\FEATURE_ZONE_ELEVATION</Key><Value>iexplore.exe</Value><RegType>REG_SZ</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Internet Explorer\PhishingFilter</Key><Value>PreventOverrideAppRepUnknown</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Internet Explorer\PhishingFilter</Key><Value>PreventOverride</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Internet Explorer\PhishingFilter</Key><Value>EnabledV9</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Internet Explorer\Restrictions</Key><Value>NoCrashDetection</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Internet Explorer\Security</Key><Value>DisableSecuritySettingsCheck</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Internet Explorer\Security\ActiveX</Key><Value>BlockNonAdminActiveXInstall</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\AxInstaller</Key><Value>OnlyUseAXISForActiveXInstall</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings</Key><Value>Security_zones_map_edit</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings</Key><Value>Security_options_edit</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings</Key><Value>Security_HKLM_only</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings</Key><Value>CertificateRevocation</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings</Key><Value>PreventIgnoreCertErrors</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings</Key><Value>WarnOnBadCertRecving</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings</Key><Value>EnableSSL3Fallback</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings</Key><Value>SecureProtocols</Value><RegType>REG_DWORD</RegType><RegData>2560</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Lockdown_Zones\0</Key><Value>1C00</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Lockdown_Zones\1</Key><Value>1C00</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Lockdown_Zones\2</Key><Value>1C00</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Lockdown_Zones\3</Key><Value>2301</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Lockdown_Zones\4</Key><Value>2301</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Lockdown_Zones\4</Key><Value>1C00</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\ZoneMap</Key><Value>UNCAsIntranet</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\0</Key><Value>1C00</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\0</Key><Value>270C</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\1</Key><Value>270C</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\1</Key><Value>1201</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\1</Key><Value>1C00</Value><RegType>REG_DWORD</RegType><RegData>65536</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\2</Key><Value>1C00</Value><RegType>REG_DWORD</RegType><RegData>65536</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\2</Key><Value>270C</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\2</Key><Value>1201</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\3</Key><Value>2001</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\3</Key><Value>2102</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\3</Key><Value>1802</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\3</Key><Value>160A</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\3</Key><Value>1201</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\3</Key><Value>1406</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\3</Key><Value>1804</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\3</Key><Value>2200</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\3</Key><Value>1209</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\3</Key><Value>1206</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\3</Key><Value>1809</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\3</Key><Value>2500</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\3</Key><Value>2103</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\3</Key><Value>1606</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\3</Key><Value>2402</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\3</Key><Value>2004</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\3</Key><Value>1C00</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\3</Key><Value>1001</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\3</Key><Value>1A00</Value><RegType>REG_DWORD</RegType><RegData>65536</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\3</Key><Value>2708</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\3</Key><Value>1004</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\3</Key><Value>120b</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\3</Key><Value>1407</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\3</Key><Value>1409</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\3</Key><Value>270C</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\3</Key><Value>1607</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\3</Key><Value>2709</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\3</Key><Value>2101</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\3</Key><Value>2301</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\3</Key><Value>1806</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\3</Key><Value>120c</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\3</Key><Value>140C</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\4</Key><Value>1608</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\4</Key><Value>1201</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\4</Key><Value>1001</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\4</Key><Value>1607</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\4</Key><Value>120b</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\4</Key><Value>1809</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\4</Key><Value>1004</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\4</Key><Value>1606</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\4</Key><Value>1407</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\4</Key><Value>160A</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\4</Key><Value>1406</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\4</Key><Value>2102</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\4</Key><Value>2004</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\4</Key><Value>2200</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\4</Key><Value>2000</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\4</Key><Value>1402</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\4</Key><Value>1803</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\4</Key><Value>2402</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\4</Key><Value>1400</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\4</Key><Value>1A00</Value><RegType>REG_DWORD</RegType><RegData>196608</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\4</Key><Value>2001</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\4</Key><Value>2500</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\4</Key><Value>1409</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\4</Key><Value>1C00</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\4</Key><Value>1209</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\4</Key><Value>270C</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\4</Key><Value>1206</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\4</Key><Value>2708</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\4</Key><Value>1802</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\4</Key><Value>2103</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\4</Key><Value>2709</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\4</Key><Value>1405</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\4</Key><Value>2101</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\4</Key><Value>2301</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\4</Key><Value>1200</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\4</Key><Value>1804</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\4</Key><Value>1806</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\4</Key><Value>120c</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\Internet Settings\Zones\4</Key><Value>140C</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{01C9ABEC-DA11-4165-B23A-9B74B8895B3F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Microsoft\WcmSvc\wifinetworkmanager\config</Key><Value>AutoConnectAllowedOEM</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Microsoft\Windows\CurrentVersion\Policies\CredUI</Key><Value>EnumerateAdministrators</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Microsoft\Windows\CurrentVersion\Policies\Explorer</Key><Value>NoDriveTypeAutoRun</Value><RegType>REG_DWORD</RegType><RegData>255</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Microsoft\Windows\CurrentVersion\Policies\Explorer</Key><Value>NoWebServices</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Microsoft\Windows\CurrentVersion\Policies\Explorer</Key><Value>NoAutorun</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Microsoft\Windows\CurrentVersion\Policies\System</Key><Value>MSAOptional</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Microsoft\Windows\CurrentVersion\Policies\System</Key><Value>DisableAutomaticRestartSignOn</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Microsoft\Windows\CurrentVersion\Policies\System</Key><Value>LocalAccountTokenFilterPolicy</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Microsoft\Windows\CurrentVersion\Policies\System\CredSSP\Parameters</Key><Value>AllowEncryptionOracle</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Biometrics\FacialFeatures</Key><Value>EnhancedAntiSpoofing</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Internet Explorer\Feeds</Key><Value>DisableEnclosureDownload</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\MicrosoftEdge\Internet Settings</Key><Value>PreventCertErrorOverrides</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\MicrosoftEdge\Main</Key><Value>FormSuggest Passwords</Value><RegType>REG_SZ</RegType><RegData>no</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\MicrosoftEdge\PhishingFilter</Key><Value>EnabledV9</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\MicrosoftEdge\PhishingFilter</Key><Value>PreventOverride</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\MicrosoftEdge\PhishingFilter</Key><Value>PreventOverrideAppRepUnknown</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Power\PowerSettings\0e796bdb-100d-47d6-a2d5-f7d2daa51f51</Key><Value>DCSettingIndex</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Power\PowerSettings\0e796bdb-100d-47d6-a2d5-f7d2daa51f51</Key><Value>ACSettingIndex</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\AppPrivacy</Key><Value>LetAppsActivateWithVoiceAboveLock</Value><RegType>REG_DWORD</RegType><RegData>2</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CloudContent</Key><Value>DisableWindowsConsumerFeatures</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\CredentialsDelegation</Key><Value>AllowProtectedCreds</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\EventLog\Application</Key><Value>MaxSize</Value><RegType>REG_DWORD</RegType><RegData>32768</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\EventLog\Security</Key><Value>MaxSize</Value><RegType>REG_DWORD</RegType><RegData>196608</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\EventLog\System</Key><Value>MaxSize</Value><RegType>REG_DWORD</RegType><RegData>32768</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\Explorer</Key><Value>NoAutoplayfornonVolume</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\GameDVR</Key><Value>AllowGameDVR</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\Group Policy\{35378EAC-683F-11D2-A89A-00C04FBBCFA2}</Key><Value>NoGPOListChanges</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\Group Policy\{35378EAC-683F-11D2-A89A-00C04FBBCFA2}</Key><Value>NoBackgroundPolicy</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\Installer</Key><Value>AlwaysInstallElevated</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\Installer</Key><Value>EnableUserControl</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\Kernel DMA Protection</Key><Value>DeviceEnumerationPolicy</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\LanmanWorkstation</Key><Value>AllowInsecureGuestAuth</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\Network Connections</Key><Value>NC_ShowSharedAccessUI</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\NetworkProvider\HardenedPaths</Key><Value>\\*\SYSVOL</Value><RegType>REG_SZ</RegType><RegData>RequireMutualAuthentication=1,RequireIntegrity=1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\NetworkProvider\HardenedPaths</Key><Value>\\*\NETLOGON</Value><RegType>REG_SZ</RegType><RegData>RequireMutualAuthentication=1,RequireIntegrity=1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\Personalization</Key><Value>NoLockScreenCamera</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\Personalization</Key><Value>NoLockScreenSlideshow</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\PowerShell\ScriptBlockLogging</Key><Value>EnableScriptBlockLogging</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\PowerShell\ScriptBlockLogging</Key><Value>**del.EnableScriptBlockInvocationLogging</Value><RegType>REG_SZ</RegType><RegData> </RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\System</Key><Value>AllowDomainPINLogon</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\System</Key><Value>EnumerateLocalUsers</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\System</Key><Value>EnableSmartScreen</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\System</Key><Value>ShellSmartScreenLevel</Value><RegType>REG_SZ</RegType><RegData>Block</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\WcmSvc\GroupPolicy</Key><Value>fBlockNonDomain</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\Windows Search</Key><Value>AllowIndexingEncryptedStoresOrItems</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\WinRM\Client</Key><Value>AllowDigest</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\WinRM\Client</Key><Value>AllowUnencryptedTraffic</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\WinRM\Client</Key><Value>AllowBasic</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\WinRM\Service</Key><Value>AllowUnencryptedTraffic</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\WinRM\Service</Key><Value>DisableRunAs</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows\WinRM\Service</Key><Value>AllowBasic</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows NT\DNSClient</Key><Value>EnableMulticast</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows NT\Printers</Key><Value>DisableWebPnPDownload</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows NT\Rpc</Key><Value>RestrictRemoteClients</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows NT\Terminal Services</Key><Value>**del.fUseMailto</Value><RegType>REG_SZ</RegType><RegData> </RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows NT\Terminal Services</Key><Value>fAllowToGetHelp</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows NT\Terminal Services</Key><Value>**del.fAllowFullControl</Value><RegType>REG_SZ</RegType><RegData> </RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows NT\Terminal Services</Key><Value>**del.MaxTicketExpiry</Value><RegType>REG_SZ</RegType><RegData> </RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows NT\Terminal Services</Key><Value>**del.MaxTicketExpiryUnits</Value><RegType>REG_SZ</RegType><RegData> </RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows NT\Terminal Services</Key><Value>MinEncryptionLevel</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows NT\Terminal Services</Key><Value>fPromptForPassword</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows NT\Terminal Services</Key><Value>fDisableCdm</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows NT\Terminal Services</Key><Value>DisablePasswordSaving</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows NT\Terminal Services</Key><Value>fEncryptRPCTraffic</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\WindowsFirewall</Key><Value>PolicyVersion</Value><RegType>REG_DWORD</RegType><RegData>538</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\WindowsFirewall\DomainProfile</Key><Value>DefaultOutboundAction</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\WindowsFirewall\DomainProfile</Key><Value>DisableNotifications</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\WindowsFirewall\DomainProfile</Key><Value>EnableFirewall</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\WindowsFirewall\DomainProfile</Key><Value>DefaultInboundAction</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\WindowsFirewall\DomainProfile\Logging</Key><Value>LogDroppedPackets</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\WindowsFirewall\DomainProfile\Logging</Key><Value>LogFileSize</Value><RegType>REG_DWORD</RegType><RegData>16384</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\WindowsFirewall\DomainProfile\Logging</Key><Value>LogSuccessfulConnections</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\WindowsFirewall\PrivateProfile</Key><Value>EnableFirewall</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\WindowsFirewall\PrivateProfile</Key><Value>DisableNotifications</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\WindowsFirewall\PrivateProfile</Key><Value>DefaultInboundAction</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\WindowsFirewall\PrivateProfile</Key><Value>DefaultOutboundAction</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\WindowsFirewall\PrivateProfile\Logging</Key><Value>LogSuccessfulConnections</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\WindowsFirewall\PrivateProfile\Logging</Key><Value>LogDroppedPackets</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\WindowsFirewall\PrivateProfile\Logging</Key><Value>LogFileSize</Value><RegType>REG_DWORD</RegType><RegData>16384</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\WindowsFirewall\PublicProfile</Key><Value>DefaultOutboundAction</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\WindowsFirewall\PublicProfile</Key><Value>EnableFirewall</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\WindowsFirewall\PublicProfile</Key><Value>DisableNotifications</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\WindowsFirewall\PublicProfile</Key><Value>AllowLocalIPsecPolicyMerge</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\WindowsFirewall\PublicProfile</Key><Value>AllowLocalPolicyMerge</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\WindowsFirewall\PublicProfile</Key><Value>DefaultInboundAction</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\WindowsFirewall\PublicProfile\Logging</Key><Value>LogFileSize</Value><RegType>REG_DWORD</RegType><RegData>16384</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\WindowsFirewall\PublicProfile\Logging</Key><Value>LogDroppedPackets</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\WindowsFirewall\PublicProfile\Logging</Key><Value>LogSuccessfulConnections</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\WindowsInkWorkspace</Key><Value>AllowWindowsInkWorkspace</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft Services\AdmPwd</Key><Value>AdmPwdEnabled</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>SYSTEM\CurrentControlSet\Control\SecurityProviders\WDigest</Key><Value>UseLogonCredential</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>SYSTEM\CurrentControlSet\Control\Session Manager\kernel</Key><Value>DisableExceptionChainValidation</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>SYSTEM\CurrentControlSet\Policies\EarlyLaunch</Key><Value>DriverLoadPolicy</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>SYSTEM\CurrentControlSet\Services\LanmanServer\Parameters</Key><Value>SMB1</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>SYSTEM\CurrentControlSet\Services\MrxSmb10</Key><Value>Start</Value><RegType>REG_DWORD</RegType><RegData>4</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>SYSTEM\CurrentControlSet\Services\Netbt\Parameters</Key><Value>NoNameReleaseOnDemand</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>SYSTEM\CurrentControlSet\Services\Netbt\Parameters</Key><Value>NodeType</Value><RegType>REG_DWORD</RegType><RegData>2</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>SYSTEM\CurrentControlSet\Services\Tcpip\Parameters</Key><Value>EnableICMPRedirect</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>SYSTEM\CurrentControlSet\Services\Tcpip\Parameters</Key><Value>DisableIPSourceRouting</Value><RegType>REG_DWORD</RegType><RegData>2</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>SYSTEM\CurrentControlSet\Services\Tcpip6\Parameters</Key><Value>DisableIPSourceRouting</Value><RegType>REG_DWORD</RegType><RegData>2</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows Defender</Key><Value>PUAProtection</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{254CCB83-EB77-4763-996C-AD7A5810FFA7}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H1 - Defender Antivirus</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows Defender\MpEngine</Key><Value>MpCloudBlockLevel</Value><RegType>REG_DWORD</RegType><RegData>2</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{254CCB83-EB77-4763-996C-AD7A5810FFA7}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H1 - Defender Antivirus</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows Defender\Real-Time Protection</Key><Value>DisableIOAVProtection</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{254CCB83-EB77-4763-996C-AD7A5810FFA7}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H1 - Defender Antivirus</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows Defender\Real-Time Protection</Key><Value>DisableRealtimeMonitoring</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{254CCB83-EB77-4763-996C-AD7A5810FFA7}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H1 - Defender Antivirus</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows Defender\Scan</Key><Value>DisableRemovableDriveScanning</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{254CCB83-EB77-4763-996C-AD7A5810FFA7}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H1 - Defender Antivirus</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows Defender\Spynet</Key><Value>SubmitSamplesConsent</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{254CCB83-EB77-4763-996C-AD7A5810FFA7}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H1 - Defender Antivirus</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows Defender\Spynet</Key><Value>SpynetReporting</Value><RegType>REG_DWORD</RegType><RegData>2</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{254CCB83-EB77-4763-996C-AD7A5810FFA7}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H1 - Defender Antivirus</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows Defender\Spynet</Key><Value>DisableBlockAtFirstSeen</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{254CCB83-EB77-4763-996C-AD7A5810FFA7}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H1 - Defender Antivirus</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows Defender\Windows Defender Exploit Guard\ASR</Key><Value>ExploitGuard_ASR_Rules</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{254CCB83-EB77-4763-996C-AD7A5810FFA7}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H1 - Defender Antivirus</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows Defender\Windows Defender Exploit Guard\ASR\Rules</Key><Value>75668c1f-73b5-4cf0-bb93-3ecf5cb7cc84</Value><RegType>REG_SZ</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{254CCB83-EB77-4763-996C-AD7A5810FFA7}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H1 - Defender Antivirus</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows Defender\Windows Defender Exploit Guard\ASR\Rules</Key><Value>3b576869-a4ec-4529-8536-b80a7769e899</Value><RegType>REG_SZ</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{254CCB83-EB77-4763-996C-AD7A5810FFA7}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H1 - Defender Antivirus</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows Defender\Windows Defender Exploit Guard\ASR\Rules</Key><Value>d4f940ab-401b-4efc-aadc-ad5f3c50688a</Value><RegType>REG_SZ</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{254CCB83-EB77-4763-996C-AD7A5810FFA7}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H1 - Defender Antivirus</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows Defender\Windows Defender Exploit Guard\ASR\Rules</Key><Value>92E97FA1-2EDF-4476-BDD6-9DD0B4DDDC7B</Value><RegType>REG_SZ</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{254CCB83-EB77-4763-996C-AD7A5810FFA7}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H1 - Defender Antivirus</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows Defender\Windows Defender Exploit Guard\ASR\Rules</Key><Value>5beb7efe-fd9a-4556-801d-275e5ffc04cc</Value><RegType>REG_SZ</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{254CCB83-EB77-4763-996C-AD7A5810FFA7}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H1 - Defender Antivirus</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows Defender\Windows Defender Exploit Guard\ASR\Rules</Key><Value>d3e037e1-3eb8-44c8-a917-57927947596d</Value><RegType>REG_SZ</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{254CCB83-EB77-4763-996C-AD7A5810FFA7}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H1 - Defender Antivirus</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows Defender\Windows Defender Exploit Guard\ASR\Rules</Key><Value>be9ba2d9-53ea-4cdc-84e5-9b1eeee46550</Value><RegType>REG_SZ</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{254CCB83-EB77-4763-996C-AD7A5810FFA7}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H1 - Defender Antivirus</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows Defender\Windows Defender Exploit Guard\ASR\Rules</Key><Value>9e6c4e1f-7d60-472f-ba1a-a39ef669e4b2</Value><RegType>REG_SZ</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{254CCB83-EB77-4763-996C-AD7A5810FFA7}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H1 - Defender Antivirus</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows Defender\Windows Defender Exploit Guard\ASR\Rules</Key><Value>b2b3f03d-6a65-4f7b-a9c7-1c7ef74a9ba4</Value><RegType>REG_SZ</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{254CCB83-EB77-4763-996C-AD7A5810FFA7}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H1 - Defender Antivirus</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows Defender\Windows Defender Exploit Guard\ASR\Rules</Key><Value>26190899-1602-49e8-8b27-eb1d0a1ce869</Value><RegType>REG_SZ</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{254CCB83-EB77-4763-996C-AD7A5810FFA7}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H1 - Defender Antivirus</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows Defender\Windows Defender Exploit Guard\ASR\Rules</Key><Value>7674ba52-37eb-4a4f-a9a1-f0f9a1619a2c</Value><RegType>REG_SZ</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{254CCB83-EB77-4763-996C-AD7A5810FFA7}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H1 - Defender Antivirus</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows Defender\Windows Defender Exploit Guard\ASR\Rules</Key><Value>c1db55ab-c21a-4637-bb3f-a12568109d35</Value><RegType>REG_SZ</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{254CCB83-EB77-4763-996C-AD7A5810FFA7}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H1 - Defender Antivirus</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows Defender\Windows Defender Exploit Guard\ASR\Rules</Key><Value>e6db77e5-3df2-4cf1-b95a-636979351e5b</Value><RegType>REG_SZ</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{254CCB83-EB77-4763-996C-AD7A5810FFA7}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H1 - Defender Antivirus</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Windows Defender\Windows Defender Exploit Guard\Network Protection</Key><Value>EnableNetworkProtection</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{254CCB83-EB77-4763-996C-AD7A5810FFA7}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H1 - Defender Antivirus</PolicyName></ComputerConfig>
<UserConfig><Key>Software\Policies\Microsoft\Internet Explorer\Control Panel</Key><Value>FormSuggest Passwords</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{30E8E787-5736-46D5-98D4-E0BAE1A16C89}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - User</PolicyName></UserConfig>
<UserConfig><Key>Software\Policies\Microsoft\Internet Explorer\Main</Key><Value>FormSuggest PW Ask</Value><RegType>REG_SZ</RegType><RegData>no</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{30E8E787-5736-46D5-98D4-E0BAE1A16C89}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - User</PolicyName></UserConfig>
<UserConfig><Key>Software\Policies\Microsoft\Internet Explorer\Main</Key><Value>FormSuggest Passwords</Value><RegType>REG_SZ</RegType><RegData>no</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{30E8E787-5736-46D5-98D4-E0BAE1A16C89}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT Internet Explorer 11 - User</PolicyName></UserConfig>
<ComputerConfig><Key>SOFTWARE\Policies\Microsoft\Windows\DeviceGuard</Key><Value>EnableVirtualizationBasedSecurity</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{B90B2AF6-574B-4DFD-9CAA-94255A1B170A}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H1 - Credential Guard</PolicyName></ComputerConfig>
<ComputerConfig><Key>SOFTWARE\Policies\Microsoft\Windows\DeviceGuard</Key><Value>RequirePlatformSecurityFeatures</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{B90B2AF6-574B-4DFD-9CAA-94255A1B170A}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H1 - Credential Guard</PolicyName></ComputerConfig>
<ComputerConfig><Key>SOFTWARE\Policies\Microsoft\Windows\DeviceGuard</Key><Value>HypervisorEnforcedCodeIntegrity</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{B90B2AF6-574B-4DFD-9CAA-94255A1B170A}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H1 - Credential Guard</PolicyName></ComputerConfig>
<ComputerConfig><Key>SOFTWARE\Policies\Microsoft\Windows\DeviceGuard</Key><Value>HVCIMATRequired</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{B90B2AF6-574B-4DFD-9CAA-94255A1B170A}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H1 - Credential Guard</PolicyName></ComputerConfig>
<ComputerConfig><Key>SOFTWARE\Policies\Microsoft\Windows\DeviceGuard</Key><Value>LsaCfgFlags</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{B90B2AF6-574B-4DFD-9CAA-94255A1B170A}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H1 - Credential Guard</PolicyName></ComputerConfig>
<ComputerConfig><Key>SOFTWARE\Policies\Microsoft\Windows\DeviceGuard</Key><Value>ConfigureSystemGuardLaunch</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{B90B2AF6-574B-4DFD-9CAA-94255A1B170A}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H1 - Credential Guard</PolicyName></ComputerConfig>
<ComputerConfig><Key>SOFTWARE\Policies\Microsoft\FVE</Key><Value>UseEnhancedPin</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{CF4F9057-F15C-4203-B217-B5A66B49E3E2}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H1 - BitLocker</PolicyName></ComputerConfig>
<ComputerConfig><Key>SOFTWARE\Policies\Microsoft\FVE</Key><Value>RDVDenyCrossOrg</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{CF4F9057-F15C-4203-B217-B5A66B49E3E2}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H1 - BitLocker</PolicyName></ComputerConfig>
<ComputerConfig><Key>SOFTWARE\Policies\Microsoft\FVE</Key><Value>DisableExternalDMAUnderLock</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{CF4F9057-F15C-4203-B217-B5A66B49E3E2}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H1 - BitLocker</PolicyName></ComputerConfig>
<ComputerConfig><Key>SOFTWARE\Policies\Microsoft\Power\PowerSettings\abfc2519-3608-4c2a-94ea-171b0ed546ab</Key><Value>DCSettingIndex</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{CF4F9057-F15C-4203-B217-B5A66B49E3E2}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H1 - BitLocker</PolicyName></ComputerConfig>
<ComputerConfig><Key>SOFTWARE\Policies\Microsoft\Power\PowerSettings\abfc2519-3608-4c2a-94ea-171b0ed546ab</Key><Value>ACSettingIndex</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{CF4F9057-F15C-4203-B217-B5A66B49E3E2}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H1 - BitLocker</PolicyName></ComputerConfig>
<ComputerConfig><Key>SOFTWARE\Policies\Microsoft\Windows\DeviceInstall\Restrictions</Key><Value>DenyDeviceClasses</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{CF4F9057-F15C-4203-B217-B5A66B49E3E2}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H1 - BitLocker</PolicyName></ComputerConfig>
<ComputerConfig><Key>SOFTWARE\Policies\Microsoft\Windows\DeviceInstall\Restrictions</Key><Value>DenyDeviceClassesRetroactive</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{CF4F9057-F15C-4203-B217-B5A66B49E3E2}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H1 - BitLocker</PolicyName></ComputerConfig>
<ComputerConfig><Key>SOFTWARE\Policies\Microsoft\Windows\DeviceInstall\Restrictions\DenyDeviceClasses</Key><Value>**delvals.</Value><RegType>REG_SZ</RegType><RegData> </RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{CF4F9057-F15C-4203-B217-B5A66B49E3E2}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H1 - BitLocker</PolicyName></ComputerConfig>
<ComputerConfig><Key>SOFTWARE\Policies\Microsoft\Windows\DeviceInstall\Restrictions\DenyDeviceClasses</Key><Value>1</Value><RegType>REG_SZ</RegType><RegData>{d48179be-ec20-11d1-b6b8-00c04fa372a7}</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{CF4F9057-F15C-4203-B217-B5A66B49E3E2}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H1 - BitLocker</PolicyName></ComputerConfig>
<ComputerConfig><Key>System\CurrentControlSet\Policies\Microsoft\FVE</Key><Value>RDVDenyWriteAccess</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{CF4F9057-F15C-4203-B217-B5A66B49E3E2}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H1 - BitLocker</PolicyName></ComputerConfig>
<UserConfig><Key>Software\Policies\Microsoft\Windows\CloudContent</Key><Value>DisableThirdPartySuggestions</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{F8A4B011-2266-4A77-8F91-842381DC8375}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H1 - User</PolicyName></UserConfig>
<UserConfig><Key>Software\Policies\Microsoft\Windows\CurrentVersion\PushNotifications</Key><Value>NoToastApplicationNotificationOnLockScreen</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{F8A4B011-2266-4A77-8F91-842381DC8375}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT Windows 10 21H1 - User</PolicyName></UserConfig>
<SecurityTemplate Section="System Access"><LineItem>LSAAnonymousNameLookup=0</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></SecurityTemplate>
<SecurityTemplate Section="Privilege Rights"><LineItem>SeSecurityPrivilege=*S-1-5-32-544</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></SecurityTemplate>
<SecurityTemplate Section="Privilege Rights"><LineItem>SeRestorePrivilege=*S-1-5-32-544</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></SecurityTemplate>
<SecurityTemplate Section="Privilege Rights"><LineItem>SeTakeOwnershipPrivilege=*S-1-5-32-544</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></SecurityTemplate>
<SecurityTemplate Section="Privilege Rights"><LineItem>SeBackupPrivilege=*S-1-5-32-544</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></SecurityTemplate>
<SecurityTemplate Section="Privilege Rights"><LineItem>SeDenyRemoteInteractiveLogonRight=*S-1-5-113</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></SecurityTemplate>
<SecurityTemplate Section="Privilege Rights"><LineItem>SeCreatePermanentPrivilege=</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></SecurityTemplate>
<SecurityTemplate Section="Privilege Rights"><LineItem>SeManageVolumePrivilege=*S-1-5-32-544</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></SecurityTemplate>
<SecurityTemplate Section="Privilege Rights"><LineItem>SeLoadDriverPrivilege=*S-1-5-32-544</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></SecurityTemplate>
<SecurityTemplate Section="Privilege Rights"><LineItem>SeLockMemoryPrivilege=</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></SecurityTemplate>
<SecurityTemplate Section="Privilege Rights"><LineItem>SeDenyNetworkLogonRight=*S-1-5-113</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></SecurityTemplate>
<SecurityTemplate Section="Privilege Rights"><LineItem>SeNetworkLogonRight=*S-1-5-32-544,*S-1-5-32-555</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></SecurityTemplate>
<SecurityTemplate Section="Privilege Rights"><LineItem>SeImpersonatePrivilege=*S-1-5-32-544,*S-1-5-6,*S-1-5-19,*S-1-5-20</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></SecurityTemplate>
<SecurityTemplate Section="Privilege Rights"><LineItem>SeCreateTokenPrivilege=</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></SecurityTemplate>
<SecurityTemplate Section="Privilege Rights"><LineItem>SeCreateGlobalPrivilege=*S-1-5-32-544,*S-1-5-6,*S-1-5-19,*S-1-5-20</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></SecurityTemplate>
<SecurityTemplate Section="Privilege Rights"><LineItem>SeSystemEnvironmentPrivilege=*S-1-5-32-544</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></SecurityTemplate>
<SecurityTemplate Section="Privilege Rights"><LineItem>SeCreatePagefilePrivilege=*S-1-5-32-544</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></SecurityTemplate>
<SecurityTemplate Section="Privilege Rights"><LineItem>SeInteractiveLogonRight=*S-1-5-32-544,*S-1-5-32-545</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></SecurityTemplate>
<SecurityTemplate Section="Privilege Rights"><LineItem>SeRemoteShutdownPrivilege=*S-1-5-32-544</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></SecurityTemplate>
<SecurityTemplate Section="Privilege Rights"><LineItem>SeDebugPrivilege=*S-1-5-32-544</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></SecurityTemplate>
<SecurityTemplate Section="Privilege Rights"><LineItem>SeTrustedCredManAccessPrivilege=</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></SecurityTemplate>
<SecurityTemplate Section="Privilege Rights"><LineItem>SeProfileSingleProcessPrivilege=*S-1-5-32-544</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></SecurityTemplate>
<SecurityTemplate Section="Privilege Rights"><LineItem>SeTcbPrivilege=</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></SecurityTemplate>
<SecurityTemplate Section="Privilege Rights"><LineItem>SeEnableDelegationPrivilege=</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></SecurityTemplate>
<SecurityTemplate Section="Service General Setting"><LineItem>&quot;XboxGipSvc&quot;,4,&quot;&quot;</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></SecurityTemplate>
<SecurityTemplate Section="Service General Setting"><LineItem>&quot;XblAuthManager&quot;,4,&quot;&quot;</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></SecurityTemplate>
<SecurityTemplate Section="Service General Setting"><LineItem>&quot;XblGameSave&quot;,4,&quot;&quot;</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></SecurityTemplate>
<SecurityTemplate Section="Service General Setting"><LineItem>&quot;XboxNetApiSvc&quot;,4,&quot;&quot;</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></SecurityTemplate>
<SecurityTemplate Section="Registry Values"><LineItem>MACHINE\Software\Microsoft\Windows NT\CurrentVersion\Winlogon\ScRemoveOption=1,&quot;1&quot;</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></SecurityTemplate>
<SecurityTemplate Section="Registry Values"><LineItem>MACHINE\Software\Microsoft\Windows\CurrentVersion\Policies\System\InactivityTimeoutSecs=4,900</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></SecurityTemplate>
<SecurityTemplate Section="Registry Values"><LineItem>MACHINE\System\CurrentControlSet\Control\Lsa\NoLMHash=4,1</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></SecurityTemplate>
<SecurityTemplate Section="Registry Values"><LineItem>MACHINE\System\CurrentControlSet\Services\LanmanWorkstation\Parameters\EnablePlainTextPassword=4,0</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></SecurityTemplate>
<SecurityTemplate Section="Registry Values"><LineItem>MACHINE\System\CurrentControlSet\Control\Lsa\LimitBlankPasswordUse=4,1</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></SecurityTemplate>
<SecurityTemplate Section="Registry Values"><LineItem>MACHINE\System\CurrentControlSet\Control\Lsa\RestrictAnonymousSAM=4,1</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></SecurityTemplate>
<SecurityTemplate Section="Registry Values"><LineItem>MACHINE\System\CurrentControlSet\Control\Lsa\RestrictAnonymous=4,1</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></SecurityTemplate>
<SecurityTemplate Section="Registry Values"><LineItem>MACHINE\System\CurrentControlSet\Services\LanManServer\Parameters\RestrictNullSessAccess=4,1</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></SecurityTemplate>
<SecurityTemplate Section="Registry Values"><LineItem>MACHINE\System\CurrentControlSet\Control\Lsa\SCENoApplyLegacyAuditPolicy=4,1</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></SecurityTemplate>
<SecurityTemplate Section="Registry Values"><LineItem>MACHINE\System\CurrentControlSet\Control\Lsa\MSV1_0\NTLMMinClientSec=4,537395200</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></SecurityTemplate>
<SecurityTemplate Section="Registry Values"><LineItem>MACHINE\System\CurrentControlSet\Control\Lsa\LmCompatibilityLevel=4,5</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></SecurityTemplate>
<SecurityTemplate Section="Registry Values"><LineItem>MACHINE\System\CurrentControlSet\Control\Lsa\MSV1_0\allownullsessionfallback=4,0</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></SecurityTemplate>
<SecurityTemplate Section="Registry Values"><LineItem>MACHINE\System\CurrentControlSet\Control\Lsa\MSV1_0\NTLMMinServerSec=4,537395200</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></SecurityTemplate>
<SecurityTemplate Section="Registry Values"><LineItem>MACHINE\System\CurrentControlSet\Services\Netlogon\Parameters\requirestrongkey=4,1</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></SecurityTemplate>
<SecurityTemplate Section="Registry Values"><LineItem>MACHINE\System\CurrentControlSet\Services\LanmanWorkstation\Parameters\RequireSecuritySignature=4,1</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></SecurityTemplate>
<SecurityTemplate Section="Registry Values"><LineItem>MACHINE\System\CurrentControlSet\Services\Netlogon\Parameters\sealsecurechannel=4,1</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></SecurityTemplate>
<SecurityTemplate Section="Registry Values"><LineItem>MACHINE\System\CurrentControlSet\Services\Netlogon\Parameters\requiresignorseal=4,1</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></SecurityTemplate>
<SecurityTemplate Section="Registry Values"><LineItem>MACHINE\System\CurrentControlSet\Services\Netlogon\Parameters\signsecurechannel=4,1</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></SecurityTemplate>
<SecurityTemplate Section="Registry Values"><LineItem>MACHINE\System\CurrentControlSet\Services\LanManServer\Parameters\requiresecuritysignature=4,1</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></SecurityTemplate>
<SecurityTemplate Section="Registry Values"><LineItem>MACHINE\System\CurrentControlSet\Control\Session Manager\ProtectionMode=4,1</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></SecurityTemplate>
<SecurityTemplate Section="Registry Values"><LineItem>MACHINE\Software\Microsoft\Windows\CurrentVersion\Policies\System\ConsentPromptBehaviorAdmin=4,2</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></SecurityTemplate>
<SecurityTemplate Section="Registry Values"><LineItem>MACHINE\Software\Microsoft\Windows\CurrentVersion\Policies\System\EnableSecureUIAPaths=4,1</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></SecurityTemplate>
<SecurityTemplate Section="Registry Values"><LineItem>MACHINE\Software\Microsoft\Windows\CurrentVersion\Policies\System\EnableLUA=4,1</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></SecurityTemplate>
<SecurityTemplate Section="Registry Values"><LineItem>MACHINE\Software\Microsoft\Windows\CurrentVersion\Policies\System\ConsentPromptBehaviorUser=4,0</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></SecurityTemplate>
<SecurityTemplate Section="Registry Values"><LineItem>MACHINE\Software\Microsoft\Windows\CurrentVersion\Policies\System\EnableInstallerDetection=4,1</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></SecurityTemplate>
<SecurityTemplate Section="Registry Values"><LineItem>MACHINE\Software\Microsoft\Windows\CurrentVersion\Policies\System\FilterAdministratorToken=4,1</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></SecurityTemplate>
<SecurityTemplate Section="Registry Values"><LineItem>MACHINE\Software\Microsoft\Windows\CurrentVersion\Policies\System\EnableVirtualization=4,1</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></SecurityTemplate>
<SecurityTemplate Section="Registry Values"><LineItem>MACHINE\System\CurrentControlSet\Services\LDAP\LDAPClientIntegrity=4,1</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></SecurityTemplate>
<SecurityTemplate Section="Registry Values"><LineItem>MACHINE\System\CurrentControlSet\Control\Lsa\RestrictRemoteSAM=1,&quot;O:BAG:BAD:(A;;RC;;;BA)&quot;</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></SecurityTemplate>
<SecurityTemplate Section="System Access"><LineItem>MinimumPasswordLength=14</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{ACB65F53-6E1D-4874-8FEC-8B58FBA50B66}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H1 - Domain Security</PolicyName></SecurityTemplate>
<SecurityTemplate Section="System Access"><LineItem>PasswordComplexity=1</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{ACB65F53-6E1D-4874-8FEC-8B58FBA50B66}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H1 - Domain Security</PolicyName></SecurityTemplate>
<SecurityTemplate Section="System Access"><LineItem>PasswordHistorySize=24</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{ACB65F53-6E1D-4874-8FEC-8B58FBA50B66}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H1 - Domain Security</PolicyName></SecurityTemplate>
<SecurityTemplate Section="System Access"><LineItem>LockoutBadCount=10</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{ACB65F53-6E1D-4874-8FEC-8B58FBA50B66}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H1 - Domain Security</PolicyName></SecurityTemplate>
<SecurityTemplate Section="System Access"><LineItem>ResetLockoutCount=15</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{ACB65F53-6E1D-4874-8FEC-8B58FBA50B66}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H1 - Domain Security</PolicyName></SecurityTemplate>
<SecurityTemplate Section="System Access"><LineItem>LockoutDuration=15</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{ACB65F53-6E1D-4874-8FEC-8B58FBA50B66}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H1 - Domain Security</PolicyName></SecurityTemplate>
<SecurityTemplate Section="System Access"><LineItem>ClearTextPassword=0</LineItem><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{ACB65F53-6E1D-4874-8FEC-8B58FBA50B66}\DomainSysvol\GPO\Machine\microsoft\windows nt\SecEdit\GptTmpl.inf</SourceFile><PolicyName>MSFT Windows 10 21H1 - Domain Security</PolicyName></SecurityTemplate>
<AuditSubcategory><GUID>{0cce923f-69ae-11d9-bed3-505054503030}</GUID><Name>Audit Credential Validation</Name><Setting>3</Setting><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\Audit\audit.csv</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></AuditSubcategory>
<AuditSubcategory><GUID>{0cce9237-69ae-11d9-bed3-505054503030}</GUID><Name>Audit Security Group Management</Name><Setting>1</Setting><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\Audit\audit.csv</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></AuditSubcategory>
<AuditSubcategory><GUID>{0cce9235-69ae-11d9-bed3-505054503030}</GUID><Name>Audit User Account Management</Name><Setting>3</Setting><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\Audit\audit.csv</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></AuditSubcategory>
<AuditSubcategory><GUID>{0cce9248-69ae-11d9-bed3-505054503030}</GUID><Name>Audit PNP Activity</Name><Setting>1</Setting><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\Audit\audit.csv</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></AuditSubcategory>
<AuditSubcategory><GUID>{0cce922b-69ae-11d9-bed3-505054503030}</GUID><Name>Audit Process Creation</Name><Setting>1</Setting><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\Audit\audit.csv</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></AuditSubcategory>
<AuditSubcategory><GUID>{0cce9217-69ae-11d9-bed3-505054503030}</GUID><Name>Audit Account Lockout</Name><Setting>2</Setting><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\Audit\audit.csv</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></AuditSubcategory>
<AuditSubcategory><GUID>{0cce9249-69ae-11d9-bed3-505054503030}</GUID><Name>Audit Group Membership</Name><Setting>1</Setting><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\Audit\audit.csv</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></AuditSubcategory>
<AuditSubcategory><GUID>{0cce9215-69ae-11d9-bed3-505054503030}</GUID><Name>Audit Logon</Name><Setting>3</Setting><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\Audit\audit.csv</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></AuditSubcategory>
<AuditSubcategory><GUID>{0cce921c-69ae-11d9-bed3-505054503030}</GUID><Name>Audit Other Logon/Logoff Events</Name><Setting>3</Setting><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\Audit\audit.csv</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></AuditSubcategory>
<AuditSubcategory><GUID>{0cce921b-69ae-11d9-bed3-505054503030}</GUID><Name>Audit Special Logon</Name><Setting>1</Setting><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\Audit\audit.csv</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></AuditSubcategory>
<AuditSubcategory><GUID>{0cce9244-69ae-11d9-bed3-505054503030}</GUID><Name>Audit Detailed File Share</Name><Setting>2</Setting><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\Audit\audit.csv</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></AuditSubcategory>
<AuditSubcategory><GUID>{0cce9224-69ae-11d9-bed3-505054503030}</GUID><Name>Audit File Share</Name><Setting>3</Setting><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\Audit\audit.csv</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></AuditSubcategory>
<AuditSubcategory><GUID>{0cce9227-69ae-11d9-bed3-505054503030}</GUID><Name>Audit Other Object Access Events</Name><Setting>3</Setting><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\Audit\audit.csv</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></AuditSubcategory>
<AuditSubcategory><GUID>{0cce9245-69ae-11d9-bed3-505054503030}</GUID><Name>Audit Removable Storage</Name><Setting>3</Setting><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\Audit\audit.csv</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></AuditSubcategory>
<AuditSubcategory><GUID>{0cce922f-69ae-11d9-bed3-505054503030}</GUID><Name>Audit Audit Policy Change</Name><Setting>1</Setting><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\Audit\audit.csv</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></AuditSubcategory>
<AuditSubcategory><GUID>{0cce9230-69ae-11d9-bed3-505054503030}</GUID><Name>Audit Authentication Policy Change</Name><Setting>1</Setting><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\Audit\audit.csv</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></AuditSubcategory>
<AuditSubcategory><GUID>{0cce9232-69ae-11d9-bed3-505054503030}</GUID><Name>Audit MPSSVC Rule-Level Policy Change</Name><Setting>3</Setting><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\Audit\audit.csv</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></AuditSubcategory>
<AuditSubcategory><GUID>{0cce9234-69ae-11d9-bed3-505054503030}</GUID><Name>Audit Other Policy Change Events</Name><Setting>2</Setting><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\Audit\audit.csv</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></AuditSubcategory>
<AuditSubcategory><GUID>{0cce9228-69ae-11d9-bed3-505054503030}</GUID><Name>Audit Sensitive Privilege Use</Name><Setting>3</Setting><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\Audit\audit.csv</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></AuditSubcategory>
<AuditSubcategory><GUID>{0cce9214-69ae-11d9-bed3-505054503030}</GUID><Name>Audit Other System Events</Name><Setting>3</Setting><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\Audit\audit.csv</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></AuditSubcategory>
<AuditSubcategory><GUID>{0cce9210-69ae-11d9-bed3-505054503030}</GUID><Name>Audit Security State Change</Name><Setting>1</Setting><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\Audit\audit.csv</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></AuditSubcategory>
<AuditSubcategory><GUID>{0cce9211-69ae-11d9-bed3-505054503030}</GUID><Name>Audit Security System Extension</Name><Setting>1</Setting><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\Audit\audit.csv</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></AuditSubcategory>
<AuditSubcategory><GUID>{0cce9212-69ae-11d9-bed3-505054503030}</GUID><Name>Audit System Integrity</Name><Setting>3</Setting><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Windows 10 - Windows 10\Windows-10-v21H1-Security-Baseline-FINAL\GPOs\{0D88597B-4C94-4F9D-AB53-EC08C7B0BBBF}\DomainSysvol\GPO\Machine\microsoft\windows nt\Audit\audit.csv</SourceFile><PolicyName>MSFT Windows 10 21H - Computer</PolicyName></AuditSubcategory>
<CSE-Machine><GUID>{2A8FDC61-2347-4C87-92F6-B05EB91A201A}</GUID><Name>Group Policy Mitigation Options</Name></CSE-Machine>
<CSE-Machine><GUID>{35378EAC-683F-11D2-A89A-00C04FBBCFA2}</GUID><Name>Registry Policy</Name></CSE-Machine>
<CSE-Machine><GUID>{827D319E-6EAC-11D2-A4EA-00C04F79F83A}</GUID><Name>Security</Name></CSE-Machine>
<CSE-Machine><GUID>{D76B9641-3288-4F75-942D-087DE603E3EA}</GUID><Name>Local Administrator Password Solution (LAPS)</Name></CSE-Machine>
<CSE-Machine><GUID>{F312195E-3D9D-447A-A3F5-08DFFA24735E}</GUID><Name>Device Guard</Name></CSE-Machine>
<CSE-Machine><GUID>{F3CCC681-B74C-4060-9F26-CD84525DCA2A}</GUID><Name>Audit Policy Configuration</Name></CSE-Machine>
<CSE-User><GUID>{35378EAC-683F-11D2-A89A-00C04FBBCFA2}</GUID><Name>Registry Policy</Name></CSE-User>
</PolicyRules>
"@

    $Windows11Profile = @"
"@

    $OfficeProfile = @"
<PolicyRules>
<ComputerConfig><Key>software\policies\microsoft\internet explorer\main\featurecontrol\FEATURE_RESTRICT_LEGACY_JSCRIPT_PER_SECURITY_ZONE</Key><Value>excel.exe</Value><RegType>REG_DWORD</RegType><RegData>69632</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{02C0F0D7-74B6-41FE-A92B-0F9F8B32A25F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Legacy JScript Block - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\policies\microsoft\internet explorer\main\featurecontrol\FEATURE_RESTRICT_LEGACY_JSCRIPT_PER_SECURITY_ZONE</Key><Value>mspub.exe</Value><RegType>REG_DWORD</RegType><RegData>69632</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{02C0F0D7-74B6-41FE-A92B-0F9F8B32A25F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Legacy JScript Block - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\policies\microsoft\internet explorer\main\featurecontrol\FEATURE_RESTRICT_LEGACY_JSCRIPT_PER_SECURITY_ZONE</Key><Value>powerpnt.exe</Value><RegType>REG_DWORD</RegType><RegData>69632</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{02C0F0D7-74B6-41FE-A92B-0F9F8B32A25F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Legacy JScript Block - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\policies\microsoft\internet explorer\main\featurecontrol\FEATURE_RESTRICT_LEGACY_JSCRIPT_PER_SECURITY_ZONE</Key><Value>onenote.exe</Value><RegType>REG_DWORD</RegType><RegData>69632</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{02C0F0D7-74B6-41FE-A92B-0F9F8B32A25F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Legacy JScript Block - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\policies\microsoft\internet explorer\main\featurecontrol\FEATURE_RESTRICT_LEGACY_JSCRIPT_PER_SECURITY_ZONE</Key><Value>visio.exe</Value><RegType>REG_DWORD</RegType><RegData>69632</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{02C0F0D7-74B6-41FE-A92B-0F9F8B32A25F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Legacy JScript Block - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\policies\microsoft\internet explorer\main\featurecontrol\FEATURE_RESTRICT_LEGACY_JSCRIPT_PER_SECURITY_ZONE</Key><Value>winproj.exe</Value><RegType>REG_DWORD</RegType><RegData>69632</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{02C0F0D7-74B6-41FE-A92B-0F9F8B32A25F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Legacy JScript Block - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\policies\microsoft\internet explorer\main\featurecontrol\FEATURE_RESTRICT_LEGACY_JSCRIPT_PER_SECURITY_ZONE</Key><Value>winword.exe</Value><RegType>REG_DWORD</RegType><RegData>69632</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{02C0F0D7-74B6-41FE-A92B-0F9F8B32A25F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Legacy JScript Block - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\policies\microsoft\internet explorer\main\featurecontrol\FEATURE_RESTRICT_LEGACY_JSCRIPT_PER_SECURITY_ZONE</Key><Value>outlook.exe</Value><RegType>REG_DWORD</RegType><RegData>69632</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{02C0F0D7-74B6-41FE-A92B-0F9F8B32A25F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Legacy JScript Block - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\policies\microsoft\internet explorer\main\featurecontrol\FEATURE_RESTRICT_LEGACY_JSCRIPT_PER_SECURITY_ZONE</Key><Value>msaccess.exe</Value><RegType>REG_DWORD</RegType><RegData>69632</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{02C0F0D7-74B6-41FE-A92B-0F9F8B32A25F}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Legacy JScript Block - Computer</PolicyName></ComputerConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\access\security</Key><Value>notbpromptunsignedaddin</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\access\security</Key><Value>blockcontentexecutionfrominternet</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\access\security</Key><Value>requireaddinsig</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\access\security\trusted locations</Key><Value>allownetworklocations</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\common</Key><Value>fbabehavior</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\common</Key><Value>fbaenabledhosts</Value><RegType>REG_EXPAND_SZ</RegType><RegData></RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\common\portal</Key><Value>linkpublishingdisabled</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\common\security</Key><Value>drmencryptproperty</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\common\security</Key><Value>openxmlencryption</Value><RegType>REG_SZ</RegType><RegData>Microsoft Enhanced RSA and AES Cryptographic Provider,AES 256,256</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\common\security</Key><Value>defaultencryption12</Value><RegType>REG_SZ</RegType><RegData>Microsoft Enhanced RSA and AES Cryptographic Provider,AES 256,256</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\common\security</Key><Value>macroruntimescanscope</Value><RegType>REG_DWORD</RegType><RegData>2</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\common\security\trusted locations</Key><Value>allow user locations</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\common\toolbars\access</Key><Value>noextensibilitycustomizationfromdocument</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\common\toolbars\excel</Key><Value>noextensibilitycustomizationfromdocument</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\common\toolbars\infopath</Key><Value>noextensibilitycustomizationfromdocument</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\common\toolbars\outlook</Key><Value>noextensibilitycustomizationfromdocument</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\common\toolbars\powerpoint</Key><Value>noextensibilitycustomizationfromdocument</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\common\toolbars\project</Key><Value>noextensibilitycustomizationfromdocument</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\common\toolbars\publisher</Key><Value>noextensibilitycustomizationfromdocument</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\common\toolbars\visio</Key><Value>noextensibilitycustomizationfromdocument</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\common\toolbars\word</Key><Value>noextensibilitycustomizationfromdocument</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\common\trustcenter</Key><Value>trustbar</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\excel\internet</Key><Value>donotloadpictures</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\excel\options</Key><Value>extractdatadisableui</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\excel\options</Key><Value>disableautorepublish</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\excel\options</Key><Value>disableautorepublishwarning</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\excel\options\binaryoptions</Key><Value>fupdateext_78_1</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\excel\security</Key><Value>extensionhardening</Value><RegType>REG_DWORD</RegType><RegData>2</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\excel\security</Key><Value>excelbypassencryptedmacroscan</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\excel\security</Key><Value>notbpromptunsignedaddin</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\excel\security</Key><Value>webservicefunctionwarnings</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\excel\security</Key><Value>blockcontentexecutionfrominternet</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\excel\security\external content</Key><Value>enableblockunsecurequeryfiles</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\excel\security\filevalidation</Key><Value>enableonload</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\excel\security\filevalidation</Key><Value>disableeditfrompv</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\excel\security\filevalidation</Key><Value>openinprotectedview</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\excel\security\protectedview</Key><Value>disableattachmentsinpv</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\excel\security\protectedview</Key><Value>disableinternetfilesinpv</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\excel\security\protectedview</Key><Value>disableunsafelocationsinpv</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\excel\security\protectedview</Key><Value>enabledatabasefileprotectedview</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\excel\security\trusted locations</Key><Value>allownetworklocations</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\ms project\security</Key><Value>notbpromptunsignedaddin</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\ms project\security</Key><Value>requireaddinsig</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\ms project\security\trusted locations</Key><Value>allownetworklocations</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\outlook</Key><Value>disallowattachmentcustomization</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\outlook\options\general</Key><Value>msgformat</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\outlook\options\mail</Key><Value>junkmailprotection</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\outlook\options\mail</Key><Value>junkmailenablelinks</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\outlook\options\mail</Key><Value>internet</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\outlook\rpc</Key><Value>enablerpcencryption</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\outlook\security</Key><Value>promptoomformulaaccess</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\outlook\security</Key><Value>promptoomsaveas</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\outlook\security</Key><Value>promptoomaddressbookaccess</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\outlook\security</Key><Value>promptoomaddressinformationaccess</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\outlook\security</Key><Value>promptoommeetingtaskrequestresponse</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\outlook\security</Key><Value>promptoomsend</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\outlook\security</Key><Value>minenckey</Value><RegType>REG_DWORD</RegType><RegData>168</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\outlook\security</Key><Value>warnaboutinvalid</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\outlook\security</Key><Value>showlevel1attach</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\outlook\security</Key><Value>promptoomcustomaction</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\outlook\security</Key><Value>enableoneoffformscripts</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\outlook\security</Key><Value>allowactivexoneoffforms</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\outlook\security</Key><Value>usecrlchasing</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\outlook\security</Key><Value>publicfolderscript</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\outlook\security</Key><Value>adminsecuritymode</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\outlook\security</Key><Value>allowuserstolowerattachments</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\outlook\security</Key><Value>sharedfolderscript</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\outlook\security</Key><Value>authenticationservice</Value><RegType>REG_DWORD</RegType><RegData>16</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\outlook\security</Key><Value>level</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\outlook\security</Key><Value>fileextensionsremovelevel1</Value><RegType>REG_SZ</RegType><RegData>;</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\outlook\security</Key><Value>fileextensionsremovelevel2</Value><RegType>REG_SZ</RegType><RegData>;</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\powerpoint\security</Key><Value>notbpromptunsignedaddin</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\powerpoint\security</Key><Value>powerpointbypassencryptedmacroscan</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\powerpoint\security</Key><Value>runprograms</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\powerpoint\security</Key><Value>blockcontentexecutionfrominternet</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\powerpoint\security</Key><Value>requireaddinsig</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\powerpoint\security\filevalidation</Key><Value>enableonload</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\powerpoint\security\filevalidation</Key><Value>disableeditfrompv</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\powerpoint\security\filevalidation</Key><Value>openinprotectedview</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\powerpoint\security\protectedview</Key><Value>disableinternetfilesinpv</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\powerpoint\security\protectedview</Key><Value>disableunsafelocationsinpv</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\powerpoint\security\protectedview</Key><Value>disableattachmentsinpv</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\powerpoint\security\trusted locations</Key><Value>allownetworklocations</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\publisher\security</Key><Value>notbpromptunsignedaddin</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\publisher\security</Key><Value>requireaddinsig</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\visio\security</Key><Value>notbpromptunsignedaddin</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\visio\security</Key><Value>blockcontentexecutionfrominternet</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\visio\security</Key><Value>requireaddinsig</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\visio\security\trusted locations</Key><Value>allownetworklocations</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\word\security</Key><Value>notbpromptunsignedaddin</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\word\security</Key><Value>wordbypassencryptedmacroscan</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\word\security</Key><Value>blockcontentexecutionfrominternet</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\word\security</Key><Value>requireaddinsig</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\word\security\filevalidation</Key><Value>openinprotectedview</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\word\security\filevalidation</Key><Value>disableeditfrompv</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\word\security\filevalidation</Key><Value>enableonload</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\word\security\protectedview</Key><Value>disableattachmentsinpv</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\word\security\protectedview</Key><Value>disableinternetfilesinpv</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\word\security\protectedview</Key><Value>disableunsafelocationsinpv</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\word\security\trusted locations</Key><Value>allownetworklocations</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\common\security</Key><Value>automationsecurity</Value><RegType>REG_DWORD</RegType><RegData>2</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\common\security</Key><Value>automationsecuritypublisher</Value><RegType>REG_DWORD</RegType><RegData>2</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\common\security</Key><Value>uficontrols</Value><RegType>REG_DWORD</RegType><RegData>6</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\common\smart tag</Key><Value>neverloadmanifests</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\vba\security</Key><Value>loadcontrolsinforms</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\vba\security</Key><Value>allowvbaintranetreferences</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\vba\security</Key><Value>disablestrictvbarefssecurity</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{1E79DACD-F0E4-4C46-BC3E-012AB1E281A5}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\excel\security\fileblock</Key><Value>dbasefiles</Value><RegType>REG_DWORD</RegType><RegData>2</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{29489F19-2CCE-4635-AA35-55CB06D75EC4}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Legacy File Block - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\excel\security\fileblock</Key><Value>difandsylkfiles</Value><RegType>REG_DWORD</RegType><RegData>2</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{29489F19-2CCE-4635-AA35-55CB06D75EC4}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Legacy File Block - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\excel\security\fileblock</Key><Value>xl2macros</Value><RegType>REG_DWORD</RegType><RegData>2</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{29489F19-2CCE-4635-AA35-55CB06D75EC4}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Legacy File Block - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\excel\security\fileblock</Key><Value>xl2worksheets</Value><RegType>REG_DWORD</RegType><RegData>2</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{29489F19-2CCE-4635-AA35-55CB06D75EC4}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Legacy File Block - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\excel\security\fileblock</Key><Value>xl3macros</Value><RegType>REG_DWORD</RegType><RegData>2</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{29489F19-2CCE-4635-AA35-55CB06D75EC4}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Legacy File Block - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\excel\security\fileblock</Key><Value>xl3worksheets</Value><RegType>REG_DWORD</RegType><RegData>2</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{29489F19-2CCE-4635-AA35-55CB06D75EC4}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Legacy File Block - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\excel\security\fileblock</Key><Value>xl4macros</Value><RegType>REG_DWORD</RegType><RegData>2</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{29489F19-2CCE-4635-AA35-55CB06D75EC4}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Legacy File Block - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\excel\security\fileblock</Key><Value>xl4workbooks</Value><RegType>REG_DWORD</RegType><RegData>2</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{29489F19-2CCE-4635-AA35-55CB06D75EC4}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Legacy File Block - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\excel\security\fileblock</Key><Value>xl4worksheets</Value><RegType>REG_DWORD</RegType><RegData>2</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{29489F19-2CCE-4635-AA35-55CB06D75EC4}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Legacy File Block - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\excel\security\fileblock</Key><Value>xl95workbooks</Value><RegType>REG_DWORD</RegType><RegData>2</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{29489F19-2CCE-4635-AA35-55CB06D75EC4}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Legacy File Block - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\excel\security\fileblock</Key><Value>xl9597workbooksandtemplates</Value><RegType>REG_DWORD</RegType><RegData>2</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{29489F19-2CCE-4635-AA35-55CB06D75EC4}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Legacy File Block - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\excel\security\fileblock</Key><Value>openinprotectedview</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{29489F19-2CCE-4635-AA35-55CB06D75EC4}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Legacy File Block - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\excel\security\fileblock</Key><Value>htmlandxmlssfiles</Value><RegType>REG_DWORD</RegType><RegData>2</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{29489F19-2CCE-4635-AA35-55CB06D75EC4}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Legacy File Block - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\excel\security\fileblock</Key><Value>xl97workbooksandtemplates</Value><RegType>REG_DWORD</RegType><RegData>2</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{29489F19-2CCE-4635-AA35-55CB06D75EC4}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Legacy File Block - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\powerpoint\security\fileblock</Key><Value>openinprotectedview</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{29489F19-2CCE-4635-AA35-55CB06D75EC4}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Legacy File Block - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\powerpoint\security\fileblock</Key><Value>binaryfiles</Value><RegType>REG_DWORD</RegType><RegData>2</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{29489F19-2CCE-4635-AA35-55CB06D75EC4}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Legacy File Block - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\visio\security\fileblock</Key><Value>visio2000files</Value><RegType>REG_DWORD</RegType><RegData>2</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{29489F19-2CCE-4635-AA35-55CB06D75EC4}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Legacy File Block - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\visio\security\fileblock</Key><Value>visio2003files</Value><RegType>REG_DWORD</RegType><RegData>2</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{29489F19-2CCE-4635-AA35-55CB06D75EC4}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Legacy File Block - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\visio\security\fileblock</Key><Value>visio50andearlierfiles</Value><RegType>REG_DWORD</RegType><RegData>2</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{29489F19-2CCE-4635-AA35-55CB06D75EC4}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Legacy File Block - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\word\security\fileblock</Key><Value>openinprotectedview</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{29489F19-2CCE-4635-AA35-55CB06D75EC4}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Legacy File Block - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\word\security\fileblock</Key><Value>word2files</Value><RegType>REG_DWORD</RegType><RegData>2</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{29489F19-2CCE-4635-AA35-55CB06D75EC4}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Legacy File Block - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\word\security\fileblock</Key><Value>word60files</Value><RegType>REG_DWORD</RegType><RegData>2</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{29489F19-2CCE-4635-AA35-55CB06D75EC4}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Legacy File Block - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\word\security\fileblock</Key><Value>word95files</Value><RegType>REG_DWORD</RegType><RegData>2</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{29489F19-2CCE-4635-AA35-55CB06D75EC4}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Legacy File Block - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\word\security\fileblock</Key><Value>word97files</Value><RegType>REG_DWORD</RegType><RegData>2</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{29489F19-2CCE-4635-AA35-55CB06D75EC4}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Legacy File Block - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\word\security\fileblock</Key><Value>word2000files</Value><RegType>REG_DWORD</RegType><RegData>2</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{29489F19-2CCE-4635-AA35-55CB06D75EC4}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Legacy File Block - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\word\security\fileblock</Key><Value>word2003files</Value><RegType>REG_DWORD</RegType><RegData>2</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{29489F19-2CCE-4635-AA35-55CB06D75EC4}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Legacy File Block - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\word\security\fileblock</Key><Value>word2007files</Value><RegType>REG_DWORD</RegType><RegData>2</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{29489F19-2CCE-4635-AA35-55CB06D75EC4}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Legacy File Block - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\word\security\fileblock</Key><Value>wordxpfiles</Value><RegType>REG_DWORD</RegType><RegData>2</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{29489F19-2CCE-4635-AA35-55CB06D75EC4}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Legacy File Block - User</PolicyName></UserConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_addon_management</Key><Value>groove.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_addon_management</Key><Value>excel.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_addon_management</Key><Value>mspub.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_addon_management</Key><Value>powerpnt.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_addon_management</Key><Value>pptview.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_addon_management</Key><Value>visio.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_addon_management</Key><Value>winproj.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_addon_management</Key><Value>winword.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_addon_management</Key><Value>outlook.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_addon_management</Key><Value>spdesign.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_addon_management</Key><Value>exprwd.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_addon_management</Key><Value>msaccess.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_addon_management</Key><Value>onenote.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_addon_management</Key><Value>mse7.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_http_username_password_disable</Key><Value>groove.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_http_username_password_disable</Key><Value>excel.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_http_username_password_disable</Key><Value>mspub.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_http_username_password_disable</Key><Value>powerpnt.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_http_username_password_disable</Key><Value>pptview.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_http_username_password_disable</Key><Value>visio.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_http_username_password_disable</Key><Value>winproj.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_http_username_password_disable</Key><Value>winword.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_http_username_password_disable</Key><Value>outlook.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_http_username_password_disable</Key><Value>spdesign.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_http_username_password_disable</Key><Value>exprwd.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_http_username_password_disable</Key><Value>msaccess.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_http_username_password_disable</Key><Value>onenote.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_http_username_password_disable</Key><Value>mse7.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_localmachine_lockdown</Key><Value>groove.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_localmachine_lockdown</Key><Value>excel.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_localmachine_lockdown</Key><Value>mspub.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_localmachine_lockdown</Key><Value>powerpnt.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_localmachine_lockdown</Key><Value>pptview.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_localmachine_lockdown</Key><Value>visio.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_localmachine_lockdown</Key><Value>winproj.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_localmachine_lockdown</Key><Value>winword.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_localmachine_lockdown</Key><Value>outlook.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_localmachine_lockdown</Key><Value>spdesign.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_localmachine_lockdown</Key><Value>exprwd.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_localmachine_lockdown</Key><Value>msaccess.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_localmachine_lockdown</Key><Value>onenote.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_localmachine_lockdown</Key><Value>mse7.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_mime_handling</Key><Value>groove.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_mime_handling</Key><Value>excel.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_mime_handling</Key><Value>mspub.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_mime_handling</Key><Value>powerpnt.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_mime_handling</Key><Value>pptview.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_mime_handling</Key><Value>visio.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_mime_handling</Key><Value>winproj.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_mime_handling</Key><Value>winword.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_mime_handling</Key><Value>outlook.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_mime_handling</Key><Value>spdesign.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_mime_handling</Key><Value>exprwd.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_mime_handling</Key><Value>msaccess.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_mime_handling</Key><Value>onenote.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_mime_handling</Key><Value>mse7.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_mime_sniffing</Key><Value>groove.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_mime_sniffing</Key><Value>excel.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_mime_sniffing</Key><Value>mspub.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_mime_sniffing</Key><Value>powerpnt.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_mime_sniffing</Key><Value>pptview.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_mime_sniffing</Key><Value>visio.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_mime_sniffing</Key><Value>winproj.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_mime_sniffing</Key><Value>winword.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_mime_sniffing</Key><Value>outlook.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_mime_sniffing</Key><Value>spdesign.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_mime_sniffing</Key><Value>exprwd.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_mime_sniffing</Key><Value>msaccess.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_mime_sniffing</Key><Value>onenote.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_mime_sniffing</Key><Value>mse7.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_object_caching</Key><Value>groove.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_object_caching</Key><Value>excel.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_object_caching</Key><Value>mspub.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_object_caching</Key><Value>powerpnt.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_object_caching</Key><Value>pptview.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_object_caching</Key><Value>visio.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_object_caching</Key><Value>winproj.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_object_caching</Key><Value>winword.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_object_caching</Key><Value>outlook.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_object_caching</Key><Value>spdesign.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_object_caching</Key><Value>exprwd.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_object_caching</Key><Value>msaccess.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_object_caching</Key><Value>onenote.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_object_caching</Key><Value>mse7.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_restrict_activexinstall</Key><Value>groove.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_restrict_activexinstall</Key><Value>excel.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_restrict_activexinstall</Key><Value>mspub.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_restrict_activexinstall</Key><Value>powerpnt.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_restrict_activexinstall</Key><Value>pptview.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_restrict_activexinstall</Key><Value>visio.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_restrict_activexinstall</Key><Value>winproj.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_restrict_activexinstall</Key><Value>winword.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_restrict_activexinstall</Key><Value>outlook.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_restrict_activexinstall</Key><Value>spdesign.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_restrict_activexinstall</Key><Value>exprwd.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_restrict_activexinstall</Key><Value>msaccess.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_restrict_activexinstall</Key><Value>onenote.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_restrict_activexinstall</Key><Value>mse7.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_restrict_filedownload</Key><Value>groove.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_restrict_filedownload</Key><Value>excel.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_restrict_filedownload</Key><Value>mspub.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_restrict_filedownload</Key><Value>powerpnt.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_restrict_filedownload</Key><Value>pptview.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_restrict_filedownload</Key><Value>visio.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_restrict_filedownload</Key><Value>winproj.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_restrict_filedownload</Key><Value>winword.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_restrict_filedownload</Key><Value>outlook.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_restrict_filedownload</Key><Value>spdesign.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_restrict_filedownload</Key><Value>exprwd.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_restrict_filedownload</Key><Value>msaccess.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_restrict_filedownload</Key><Value>onenote.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_restrict_filedownload</Key><Value>mse7.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_securityband</Key><Value>groove.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_securityband</Key><Value>excel.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_securityband</Key><Value>mspub.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_securityband</Key><Value>powerpnt.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_securityband</Key><Value>pptview.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_securityband</Key><Value>visio.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_securityband</Key><Value>winproj.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_securityband</Key><Value>winword.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_securityband</Key><Value>outlook.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_securityband</Key><Value>spdesign.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_securityband</Key><Value>exprwd.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_securityband</Key><Value>msaccess.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_securityband</Key><Value>onenote.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_securityband</Key><Value>mse7.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_unc_savedfilecheck</Key><Value>groove.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_unc_savedfilecheck</Key><Value>excel.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_unc_savedfilecheck</Key><Value>mspub.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_unc_savedfilecheck</Key><Value>powerpnt.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_unc_savedfilecheck</Key><Value>pptview.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_unc_savedfilecheck</Key><Value>visio.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_unc_savedfilecheck</Key><Value>winproj.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_unc_savedfilecheck</Key><Value>winword.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_unc_savedfilecheck</Key><Value>outlook.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_unc_savedfilecheck</Key><Value>spdesign.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_unc_savedfilecheck</Key><Value>exprwd.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_unc_savedfilecheck</Key><Value>msaccess.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_unc_savedfilecheck</Key><Value>onenote.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_unc_savedfilecheck</Key><Value>mse7.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_validate_navigate_url</Key><Value>groove.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_validate_navigate_url</Key><Value>excel.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_validate_navigate_url</Key><Value>mspub.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_validate_navigate_url</Key><Value>powerpnt.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_validate_navigate_url</Key><Value>pptview.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_validate_navigate_url</Key><Value>visio.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_validate_navigate_url</Key><Value>winproj.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_validate_navigate_url</Key><Value>winword.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_validate_navigate_url</Key><Value>outlook.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_validate_navigate_url</Key><Value>spdesign.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_validate_navigate_url</Key><Value>exprwd.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_validate_navigate_url</Key><Value>msaccess.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_validate_navigate_url</Key><Value>onenote.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_validate_navigate_url</Key><Value>mse7.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_window_restrictions</Key><Value>groove.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_window_restrictions</Key><Value>excel.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_window_restrictions</Key><Value>mspub.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_window_restrictions</Key><Value>powerpnt.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_window_restrictions</Key><Value>pptview.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_window_restrictions</Key><Value>visio.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_window_restrictions</Key><Value>winproj.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_window_restrictions</Key><Value>winword.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_window_restrictions</Key><Value>outlook.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_window_restrictions</Key><Value>spdesign.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_window_restrictions</Key><Value>exprwd.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_window_restrictions</Key><Value>msaccess.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_window_restrictions</Key><Value>onenote.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_window_restrictions</Key><Value>mse7.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_zone_elevation</Key><Value>groove.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_zone_elevation</Key><Value>excel.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_zone_elevation</Key><Value>mspub.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_zone_elevation</Key><Value>powerpnt.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_zone_elevation</Key><Value>pptview.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_zone_elevation</Key><Value>visio.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_zone_elevation</Key><Value>winproj.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_zone_elevation</Key><Value>winword.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_zone_elevation</Key><Value>outlook.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_zone_elevation</Key><Value>spdesign.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_zone_elevation</Key><Value>exprwd.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_zone_elevation</Key><Value>msaccess.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_zone_elevation</Key><Value>onenote.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\internet explorer\main\featurecontrol\feature_zone_elevation</Key><Value>mse7.exe</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\Office\16.0\Common\COM Compatibility\{D27CDB6E-AE6D-11CF-96B8-444553540000}</Key><Value>ActivationFilterOverride</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\Office\16.0\Common\COM Compatibility\{D27CDB6E-AE6D-11CF-96B8-444553540000}</Key><Value>Compatibility Flags</Value><RegType>REG_DWORD</RegType><RegData>1024</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\Office\16.0\Common\COM Compatibility\{D27CDB70-AE6D-11CF-96B8-444553540000}</Key><Value>ActivationFilterOverride</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\Office\16.0\Common\COM Compatibility\{D27CDB70-AE6D-11CF-96B8-444553540000}</Key><Value>Compatibility Flags</Value><RegType>REG_DWORD</RegType><RegData>1024</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\Office\Common\COM Compatibility</Key><Value>Comment</Value><RegType>REG_SZ</RegType><RegData>Block all Flash activation</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\Office\Common\COM Compatibility\{D27CDB6E-AE6D-11CF-96B8-444553540000}</Key><Value>ActivationFilterOverride</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\Office\Common\COM Compatibility\{D27CDB6E-AE6D-11CF-96B8-444553540000}</Key><Value>Compatibility Flags</Value><RegType>REG_DWORD</RegType><RegData>1024</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\Office\Common\COM Compatibility\{D27CDB70-AE6D-11CF-96B8-444553540000}</Key><Value>ActivationFilterOverride</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\microsoft\Office\Common\COM Compatibility\{D27CDB70-AE6D-11CF-96B8-444553540000}</Key><Value>Compatibility Flags</Value><RegType>REG_DWORD</RegType><RegData>1024</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\policies\microsoft\office\16.0\lync</Key><Value>disablehttpconnect</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\policies\microsoft\office\16.0\lync</Key><Value>enablesiphighsecuritymode</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\WOW6432Node\Microsoft\Office\16.0\Common\COM Compatibility\{D27CDB6E-AE6D-11CF-96B8-444553540000}</Key><Value>ActivationFilterOverride</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\WOW6432Node\Microsoft\Office\16.0\Common\COM Compatibility\{D27CDB6E-AE6D-11CF-96B8-444553540000}</Key><Value>Compatibility Flags</Value><RegType>REG_DWORD</RegType><RegData>1024</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\WOW6432Node\Microsoft\Office\16.0\Common\COM Compatibility\{D27CDB70-AE6D-11CF-96B8-444553540000}</Key><Value>ActivationFilterOverride</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\WOW6432Node\Microsoft\Office\16.0\Common\COM Compatibility\{D27CDB70-AE6D-11CF-96B8-444553540000}</Key><Value>Compatibility Flags</Value><RegType>REG_DWORD</RegType><RegData>1024</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\WOW6432Node\Microsoft\Office\Common\COM Compatibility\{D27CDB6E-AE6D-11CF-96B8-444553540000}</Key><Value>ActivationFilterOverride</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\WOW6432Node\Microsoft\Office\Common\COM Compatibility\{D27CDB6E-AE6D-11CF-96B8-444553540000}</Key><Value>Compatibility Flags</Value><RegType>REG_DWORD</RegType><RegData>1024</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\WOW6432Node\Microsoft\Office\Common\COM Compatibility\{D27CDB70-AE6D-11CF-96B8-444553540000}</Key><Value>ActivationFilterOverride</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>software\WOW6432Node\Microsoft\Office\Common\COM Compatibility\{D27CDB70-AE6D-11CF-96B8-444553540000}</Key><Value>Compatibility Flags</Value><RegType>REG_DWORD</RegType><RegData>1024</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{52C7424B-D757-480D-8E3C-EB99CCC56AD8}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Computer</PolicyName></ComputerConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\excel\security\external content</Key><Value>disableddeserverlaunch</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{BA1AA3BB-2479-4C9A-B86D-480FDD48DEB9}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - DDE Block - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\excel\security\external content</Key><Value>disableddeserverlookup</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{BA1AA3BB-2479-4C9A-B86D-480FDD48DEB9}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - DDE Block - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\word\security</Key><Value>**del.allowdde</Value><RegType>REG_SZ</RegType><RegData> </RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{BA1AA3BB-2479-4C9A-B86D-480FDD48DEB9}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - DDE Block - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\access\security</Key><Value>vbawarnings</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{F3B1FCE6-9462-4D64-AE70-29E4344D20F1}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Require Macro Signing - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\access\security</Key><Value>vbadigsigtrustedpublishers</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{F3B1FCE6-9462-4D64-AE70-29E4344D20F1}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Require Macro Signing - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\access\security</Key><Value>vbarequirelmtrustedpublisher</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{F3B1FCE6-9462-4D64-AE70-29E4344D20F1}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Require Macro Signing - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\access\security</Key><Value>vbarequiredigsigwithcodesigningeku</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{F3B1FCE6-9462-4D64-AE70-29E4344D20F1}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Require Macro Signing - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\excel\security</Key><Value>vbawarnings</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{F3B1FCE6-9462-4D64-AE70-29E4344D20F1}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Require Macro Signing - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\excel\security</Key><Value>vbadigsigtrustedpublishers</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{F3B1FCE6-9462-4D64-AE70-29E4344D20F1}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Require Macro Signing - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\excel\security</Key><Value>vbarequirelmtrustedpublisher</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{F3B1FCE6-9462-4D64-AE70-29E4344D20F1}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Require Macro Signing - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\excel\security</Key><Value>vbarequiredigsigwithcodesigningeku</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{F3B1FCE6-9462-4D64-AE70-29E4344D20F1}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Require Macro Signing - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\ms project\security</Key><Value>vbawarnings</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{F3B1FCE6-9462-4D64-AE70-29E4344D20F1}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Require Macro Signing - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\powerpoint\security</Key><Value>vbawarnings</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{F3B1FCE6-9462-4D64-AE70-29E4344D20F1}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Require Macro Signing - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\powerpoint\security</Key><Value>vbadigsigtrustedpublishers</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{F3B1FCE6-9462-4D64-AE70-29E4344D20F1}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Require Macro Signing - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\powerpoint\security</Key><Value>vbarequirelmtrustedpublisher</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{F3B1FCE6-9462-4D64-AE70-29E4344D20F1}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Require Macro Signing - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\powerpoint\security</Key><Value>vbarequiredigsigwithcodesigningeku</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{F3B1FCE6-9462-4D64-AE70-29E4344D20F1}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Require Macro Signing - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\publisher\security</Key><Value>vbawarnings</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{F3B1FCE6-9462-4D64-AE70-29E4344D20F1}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Require Macro Signing - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\publisher\security</Key><Value>vbadigsigtrustedpublishers</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{F3B1FCE6-9462-4D64-AE70-29E4344D20F1}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Require Macro Signing - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\publisher\security</Key><Value>vbarequirelmtrustedpublisher</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{F3B1FCE6-9462-4D64-AE70-29E4344D20F1}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Require Macro Signing - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\publisher\security</Key><Value>vbarequiredigsigwithcodesigningeku</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{F3B1FCE6-9462-4D64-AE70-29E4344D20F1}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Require Macro Signing - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\visio\security</Key><Value>vbawarnings</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{F3B1FCE6-9462-4D64-AE70-29E4344D20F1}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Require Macro Signing - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\visio\security</Key><Value>vbadigsigtrustedpublishers</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{F3B1FCE6-9462-4D64-AE70-29E4344D20F1}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Require Macro Signing - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\visio\security</Key><Value>vbarequirelmtrustedpublisher</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{F3B1FCE6-9462-4D64-AE70-29E4344D20F1}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Require Macro Signing - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\visio\security</Key><Value>vbarequiredigsigwithcodesigningeku</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{F3B1FCE6-9462-4D64-AE70-29E4344D20F1}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Require Macro Signing - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\word\security</Key><Value>vbawarnings</Value><RegType>REG_DWORD</RegType><RegData>3</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{F3B1FCE6-9462-4D64-AE70-29E4344D20F1}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Require Macro Signing - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\word\security</Key><Value>vbadigsigtrustedpublishers</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{F3B1FCE6-9462-4D64-AE70-29E4344D20F1}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Require Macro Signing - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\word\security</Key><Value>vbarequirelmtrustedpublisher</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{F3B1FCE6-9462-4D64-AE70-29E4344D20F1}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Require Macro Signing - User</PolicyName></UserConfig>
<UserConfig><Key>software\policies\microsoft\office\16.0\word\security</Key><Value>vbarequiredigsigwithcodesigningeku</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\OneDrive - Microsoft\Desktop\Microsoft 365 Apps for Enterprise-2104-FINAL\GPOs\{F3B1FCE6-9462-4D64-AE70-29E4344D20F1}\DomainSysvol\GPO\User\registry.pol</SourceFile><PolicyName>MSFT M365 Apps for enterprise 2104 - Require Macro Signing - User</PolicyName></UserConfig>
<CSE-Machine><GUID>{35378EAC-683F-11D2-A89A-00C04FBBCFA2}</GUID><Name>Registry Policy</Name></CSE-Machine>
<CSE-User><GUID>{35378EAC-683F-11D2-A89A-00C04FBBCFA2}</GUID><Name>Registry Policy</Name></CSE-User>
</PolicyRules>
"@

    $EdgeProfile = @"
<PolicyRules>
<ComputerConfig><Key>Software\Policies\Microsoft\Edge</Key><Value>SitePerProcess</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Edge - Edge\Microsoft-Edge-v93-Security-Baseline-FINAL\GPOs\{C8A8CFD4-6D2E-4AD0-9E00-E8926FAA0A63}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Edge Version 93 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Edge</Key><Value>SSLVersionMin</Value><RegType>REG_SZ</RegType><RegData>tls1.2</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Edge - Edge\Microsoft-Edge-v93-Security-Baseline-FINAL\GPOs\{C8A8CFD4-6D2E-4AD0-9E00-E8926FAA0A63}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Edge Version 93 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Edge</Key><Value>AuthSchemes</Value><RegType>REG_SZ</RegType><RegData>ntlm,negotiate</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Edge - Edge\Microsoft-Edge-v93-Security-Baseline-FINAL\GPOs\{C8A8CFD4-6D2E-4AD0-9E00-E8926FAA0A63}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Edge Version 93 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Edge</Key><Value>NativeMessagingUserLevelHosts</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Edge - Edge\Microsoft-Edge-v93-Security-Baseline-FINAL\GPOs\{C8A8CFD4-6D2E-4AD0-9E00-E8926FAA0A63}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Edge Version 93 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Edge</Key><Value>PasswordManagerEnabled</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Edge - Edge\Microsoft-Edge-v93-Security-Baseline-FINAL\GPOs\{C8A8CFD4-6D2E-4AD0-9E00-E8926FAA0A63}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Edge Version 93 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Edge</Key><Value>SmartScreenEnabled</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Edge - Edge\Microsoft-Edge-v93-Security-Baseline-FINAL\GPOs\{C8A8CFD4-6D2E-4AD0-9E00-E8926FAA0A63}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Edge Version 93 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Edge</Key><Value>PreventSmartScreenPromptOverride</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Edge - Edge\Microsoft-Edge-v93-Security-Baseline-FINAL\GPOs\{C8A8CFD4-6D2E-4AD0-9E00-E8926FAA0A63}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Edge Version 93 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Edge</Key><Value>PreventSmartScreenPromptOverrideForFiles</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Edge - Edge\Microsoft-Edge-v93-Security-Baseline-FINAL\GPOs\{C8A8CFD4-6D2E-4AD0-9E00-E8926FAA0A63}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Edge Version 93 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Edge</Key><Value>SSLErrorOverrideAllowed</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Edge - Edge\Microsoft-Edge-v93-Security-Baseline-FINAL\GPOs\{C8A8CFD4-6D2E-4AD0-9E00-E8926FAA0A63}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Edge Version 93 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Edge</Key><Value>SmartScreenPuaEnabled</Value><RegType>REG_DWORD</RegType><RegData>1</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Edge - Edge\Microsoft-Edge-v93-Security-Baseline-FINAL\GPOs\{C8A8CFD4-6D2E-4AD0-9E00-E8926FAA0A63}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Edge Version 93 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Edge</Key><Value>BasicAuthOverHttpEnabled</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Edge - Edge\Microsoft-Edge-v93-Security-Baseline-FINAL\GPOs\{C8A8CFD4-6D2E-4AD0-9E00-E8926FAA0A63}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Edge Version 93 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Edge</Key><Value>InternetExplorerIntegrationReloadInIEModeAllowed</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Edge - Edge\Microsoft-Edge-v93-Security-Baseline-FINAL\GPOs\{C8A8CFD4-6D2E-4AD0-9E00-E8926FAA0A63}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Edge Version 93 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Edge</Key><Value>SharedArrayBufferUnrestrictedAccessAllowed</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Edge - Edge\Microsoft-Edge-v93-Security-Baseline-FINAL\GPOs\{C8A8CFD4-6D2E-4AD0-9E00-E8926FAA0A63}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Edge Version 93 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Edge</Key><Value>InsecurePrivateNetworkRequestsAllowed</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Edge - Edge\Microsoft-Edge-v93-Security-Baseline-FINAL\GPOs\{C8A8CFD4-6D2E-4AD0-9E00-E8926FAA0A63}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Edge Version 93 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Edge</Key><Value>TripleDESEnabled</Value><RegType>REG_DWORD</RegType><RegData>0</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Edge - Edge\Microsoft-Edge-v93-Security-Baseline-FINAL\GPOs\{C8A8CFD4-6D2E-4AD0-9E00-E8926FAA0A63}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Edge Version 93 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Edge\ExtensionInstallBlocklist</Key><Value>**delvals.</Value><RegType>REG_SZ</RegType><RegData> </RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Edge - Edge\Microsoft-Edge-v93-Security-Baseline-FINAL\GPOs\{C8A8CFD4-6D2E-4AD0-9E00-E8926FAA0A63}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Edge Version 93 - Computer</PolicyName></ComputerConfig>
<ComputerConfig><Key>Software\Policies\Microsoft\Edge\ExtensionInstallBlocklist</Key><Value>1</Value><RegType>REG_SZ</RegType><RegData>*</RegData><SourceFile>C:\Users\jmunck\Microsoft\Microsoft Security Compliance Toolkit - Edge - Edge\Microsoft-Edge-v93-Security-Baseline-FINAL\GPOs\{C8A8CFD4-6D2E-4AD0-9E00-E8926FAA0A63}\DomainSysvol\GPO\Machine\registry.pol</SourceFile><PolicyName>MSFT Edge Version 93 - Computer</PolicyName></ComputerConfig>
<CSE-Machine><GUID>{35378EAC-683F-11D2-A89A-00C04FBBCFA2}</GUID><Name>Registry Policy</Name></CSE-Machine>
</PolicyRules>
"@

    switch ($BaselineProfile) {
        "Windows10" { $InputProfile = $Windows10Profile }
        "Windows11" { $InputProfile = $Windows11Profile }
        "Office"    { $InputProfile = $OfficeProfile }
        "Edge"      { $InputProfile = $EdgeProfile }
        default {
            # If no profile is provided, try to determine it automatically
            $OsVersion = [System.Environment]::OSVersion.Version
            $Item = Get-ItemProperty -Path "Registry::HKLM\SYSTEM\CurrentControlSet\Control\ProductOptions" -ErrorAction SilentlyContinue -ErrorVariable GetItemPropertyError
            switch ($Item.ProductType) {
                "WinNT" {
                    switch ($OsVersion.Major) {
                        10 { $InputProfile = $Windows10Profile }
                        11 { $InputProfile = $Windows11Profile }
                    }
                }
                "ServerNT" { throw "Not implemented" }
                "LanmanNT" { throw "Not implemented" }
            }
        }
    }

    [xml] $XmlProfile = $InputProfile

    switch ($Category) {
        "ComputerConfig" {
            foreach ($Property in $XmlProfile.GetElementsByTagName($_)) {
                if ($Property.Key.StartsWith("**del") -or $Property.Value.StartsWith("**del")) { continue }
                $Element = New-Object -TypeName PSObject
                $Element | Add-Member -MemberType "NoteProperty" -Name "PolicyName" -Value $Property.PolicyName
                $Element | Add-Member -MemberType "NoteProperty" -Name "Key" -Value "HKLM\$($Property.Key)"
                $Element | Add-Member -MemberType "NoteProperty" -Name "Value" -Value $Property.Value
                $Element | Add-Member -MemberType "NoteProperty" -Name "RegType" -Value $Property.RegType
                $Element | Add-Member -MemberType "NoteProperty" -Name "RegData" -Value $Property.RegData
                $Element
            }
        }
        "UserConfig" {
            foreach ($Property in $XmlProfile.GetElementsByTagName($_)) {
                if ($Property.Key.StartsWith("**del") -or $Property.Value.StartsWith("**del")) { continue }
                $Element = New-Object -TypeName PSObject
                $Element | Add-Member -MemberType "NoteProperty" -Name "PolicyName" -Value $Property.PolicyName
                $Element | Add-Member -MemberType "NoteProperty" -Name "Key" -Value "HKCU\$($Property.Key)"
                $Element | Add-Member -MemberType "NoteProperty" -Name "Value" -Value $Property.Value
                $Element | Add-Member -MemberType "NoteProperty" -Name "RegType" -Value $Property.RegType
                $Element | Add-Member -MemberType "NoteProperty" -Name "RegData" -Value $Property.RegData
                $Element
            }
        }
        "SecurityTemplate" {
            foreach ($Property in $XmlProfile.GetElementsByTagName($_)) {
                $Element = New-Object -TypeName PSObject
                $Element | Add-Member -MemberType "NoteProperty" -Name "PolicyName" -Value $Property.PolicyName
                $Element | Add-Member -MemberType "NoteProperty" -Name "Section" -Value $Property.Section
                $Element | Add-Member -MemberType "NoteProperty" -Name "LineItem" -Value $Property.LineItem
                $Element
            }
        }
        "AuditSubcategory" {
            foreach ($Property in $XmlProfile.GetElementsByTagName($_)) {
                $Element = New-Object -TypeName PSObject
                $Element | Add-Member -MemberType "NoteProperty" -Name "PolicyName" -Value $Property.PolicyName
                $Element | Add-Member -MemberType "NoteProperty" -Name "GUID" -Value $Property.GUID
                $Element | Add-Member -MemberType "NoteProperty" -Name "Name" -Value $Property.Name
                $Element | Add-Member -MemberType "NoteProperty" -Name "Setting" -Value $Property.Setting
                $Element
            }
        }
        "CSE-Machine" {
            foreach ($Property in $XmlProfile.GetElementsByTagName($_)) {
                $Element = New-Object -TypeName PSObject
                $Element | Add-Member -MemberType "NoteProperty" -Name "GUID" -Value $Property.GUID
                $Element | Add-Member -MemberType "NoteProperty" -Name "Name" -Value $Property.Name
                $Element
            }
        }
        "CSE-User" {
            foreach ($Property in $XmlProfile.GetElementsByTagName($_)) {
                $Element = New-Object -TypeName PSObject
                $Element | Add-Member -MemberType "NoteProperty" -Name "GUID" -Value $Property.GUID
                $Element | Add-Member -MemberType "NoteProperty" -Name "Name" -Value $Property.Name
                $Element
            }
        }
    }
}

function Invoke-BaselineRegistryAudit {

    [CmdletBinding()] Param(
        [Parameter(Mandatory=$true)]
        [object]
        $BaselineItem
    )

    switch ($BaselineItem.RegType) {
        "REG_DWORD" {
            $ExpectedValue = [UInt32] $BaselineItem.RegData
        }
        "REG_SZ" {
            $ExpectedValue = [string] $BaselineItem.RegData
        }
        "REG_EXPAND_SZ" {
            $ExpectedValue = [string] $BaselineItem.RegData
        }
        default {
            throw "Unhandled registry type value"
        }
    }

    $Item = Get-ItemProperty -Path "Registry::$($BaselineItem.Key)" -Name $BaselineItem.Value -ErrorAction SilentlyContinue -ErrorVariable ErrorGetItemProperty
    $ValueToCheck = $Item.$($BaselineItem.Value)


    $BaselineItem | Add-Member -MemberType "NoteProperty" -Name "State" -Value $ValueToCheck
    $BaselineItem | Add-Member -MemberType "NoteProperty" -Name "Compliant" -Value $($ValueToCheck -eq $ExpectedValue)
    $BaselineItem
}

function ConvertTo-RegistryBaselineItem {
    <#
    .SYNOPSIS
    Short description
    
    .DESCRIPTION
    Long description
    
    .PARAMETER SecurityTemplate
    Parameter description
    
    .EXAMPLE
    An example
    
    .NOTES
    MACHINE\System\CurrentControlSet\Control\Lsa\MSV1_0\allownullsessionfallback=4,0 <- Expected value
    ^       ^                                           ^                        ^
    |       |                                           |                        |
    Hive    Key                                         Value                    RegType (enum value)
    #>
    
    [CmdletBinding()] Param(
        [object]
        $SecurityTemplate
    )

    if (-not ($SecurityTemplate.Section -like "Registry Values")) { return }

    $LineItem = $SecurityTemplate.LineItem
    # MACHINE\System\CurrentControlSet\Control\Lsa\MSV1_0\allownullsessionfallback=4,0

    $LineItemSplit = $LineItem.Split(",")
    $RegData = $LineItemSplit[1]
    $LineItem = $LineItemSplit[0]
    # MACHINE\System\CurrentControlSet\Control\Lsa\MSV1_0\allownullsessionfallback=4

    $LineItemSplit = $LineItem.Split("=")
    $RegTypeId = [UInt32] $LineItemSplit[1]
    $LineItem = $LineItemSplit[0]
    # MACHINE\System\CurrentControlSet\Control\Lsa\MSV1_0\allownullsessionfallback

    $LineItemSplit = $LineItem.Split("\")
    $HiveName = $LineItemSplit[0]
    $Key = $LineItemSplit[1..($LineItemSplit.length - 2)] -join "\"
    $Value = $LineItemSplit[$LineItemSplit.length - 1]
    
    switch ($HiveName) {
        "MACHINE" { $Hive = "HKLM" }
        "USER" { $Hive = "HKCU" }
        default { throw "Unknown hive name" }
    }

    switch ($RegTypeId) {
        1 { $RegType = "REG_SZ" }
        2 { $RegType = "REG_EXPAND_SZ" }
        3 { $RegType = "REG_BINARY" }
        4 { $RegType = "REG_DWORD" }
        7 { $RegType = "REG_MULTI_SZ" }
        11 { $RegType = "REG_QWORD" }
        default { throw "Unknown registry value type id" }
    }

    $BaselineItem = New-Object -TypeName PSObject
    $BaselineItem | Add-Member -MemberType "NoteProperty" -Name "PolicyName" -Value $SecurityTemplate.PolicyName
    $BaselineItem | Add-Member -MemberType "NoteProperty" -Name "Key" -Value "$Hive\$($Key)"
    $BaselineItem | Add-Member -MemberType "NoteProperty" -Name "Value" -Value $Value
    $BaselineItem | Add-Member -MemberType "NoteProperty" -Name "RegType" -Value $RegType
    $BaselineItem | Add-Member -MemberType "NoteProperty" -Name "RegData" -Value $RegData
    $BaselineItem
}

function Invoke-BaselineAudit {

    [CmdletBinding()] Param(
        [Parameter(Mandatory=$true)]
        [ValidateSet("Internet Explorer", "Computer", "User", "Defender Antivirus", "Credential Guard", "BitLocker", "Domain Security", "OfficeComputer", "OfficeUser", "EdgeComputer")]
        [string]
        $Category
    )

    $MachineRole = $((Invoke-MachineRoleCheck).Role)

    switch ($Category) {
        "Internet Explorer" {
            $Baseline = Get-SecurityBaseline -Category "ComputerConfig" | Where-Object { $_.PolicyName -Like "*Internet Explorer*" }
            $Baseline += Get-SecurityBaseline -Category "UserConfig" | Where-Object { $_.PolicyName -Like "*Internet Explorer*" }
            $Baseline | Where-Object { $null -ne $_} | ForEach-Object { Invoke-BaselineRegistryAudit -BaselineItem $_ }
        }
        "Computer" {
            Invoke-ComputerBaselineAudit -Role $MachineRole
        }
        "User" {
            $Baseline = Get-SecurityBaseline -Category "UserConfig" | Where-Object { $_.PolicyName -Like "*User*" }
            $Baseline | Where-Object { $null -ne $_ } | ForEach-Object { Invoke-BaselineRegistryAudit -BaselineItem $_ }
        }
        "Defender Antivirus" {
            $Baseline = Get-SecurityBaseline -Category "ComputerConfig" | Where-Object { $_.PolicyName -Like "*Defender Antivirus*" }
            $Baseline | Where-Object { $null -ne $_ } | ForEach-Object { Invoke-BaselineRegistryAudit -BaselineItem $_ }
        }
        "Credential Guard" {
            $Baseline = Get-SecurityBaseline -Category "ComputerConfig" | Where-Object { $_.PolicyName -Like "*Credential Guard*" }
            $Baseline | Where-Object { $null -ne $_ } | ForEach-Object { Invoke-BaselineRegistryAudit -BaselineItem $_ }
        }
        "BitLocker" {
            $Baseline = Get-SecurityBaseline -Category "ComputerConfig" | Where-Object { $_.PolicyName -Like "*BitLocker*" }
            $Baseline | Where-Object { $null -ne $_ } | ForEach-Object { Invoke-BaselineRegistryAudit -BaselineItem $_ }
        }
        "Domain Security" {
            throw "Domain Security category is not implemented"
        }
        "OfficeComputer" {
            $Baseline = Get-SecurityBaseline -BaselineProfile "Office" -Category "ComputerConfig"
            $Baseline | Where-Object { $null -ne $_ } | ForEach-Object { Invoke-BaselineRegistryAudit -BaselineItem $_ }
        }
        "OfficeUser" {
            $Baseline = Get-SecurityBaseline -BaselineProfile "Office" -Category "UserConfig"
            $Baseline | Where-Object { $null -ne $_ } | ForEach-Object { Invoke-BaselineRegistryAudit -BaselineItem $_ }
        }
        "EdgeComputer" {
            $Baseline = Get-SecurityBaseline -BaselineProfile "Edge" -Category "ComputerConfig"
            $Baseline | Where-Object { $null -ne $_ } | ForEach-Object { Invoke-BaselineRegistryAudit -BaselineItem $_ }
        }
    }
}

function Invoke-ComputerBaselineAudit {
    <#
    .SYNOPSIS
    Short description
    
    .DESCRIPTION
    Long description
    
    .PARAMETER Role
    Parameter description
    
    .NOTES
    Policy name sample values:
        - MSFT Windows 10 21H - Computer
        - MSFT Windows Server 2004 - Member Server
        - MSFT Windows Server 2004 - Domain Controller
    #>

    [CmdletBinding()] Param(
        [Parameter(Mandatory=$true)]
        [ValidateSet("Workstation", "Server", "Domain Controller")]
        [string]
        $Role
    )

    switch ($Role) {
        "Workstation" { $Filter = "*Computer*" }
        "Server" { $Filter = "*Member Server*" }
        "Domain Controller" { $Filter = "*Domain Controller*" }
    }

    # Get registry values from Computer and User config
    $Baseline = Get-SecurityBaseline -Category "ComputerConfig" | Where-Object { $_.PolicyName -Like "*Windows*" -and $_.PolicyName -Like $Filter }
    $Baseline += Get-SecurityBaseline -Category "UserConfig" | Where-Object { $_.PolicyName -Like "*Windows*" -and $_.PolicyName -Like $Filter }

    # Get registry values from security templates
    $BaselineTemp = Get-SecurityBaseline -Category "SecurityTemplate" | Where-Object { $_.PolicyName -Like "*Windows*" -and $_.PolicyName -Like $Filter }
    $Baseline += $BaselineTemp | ForEach-Object { ConvertTo-RegistryBaselineItem -SecurityTemplate $_ }
    
    $Baseline | Where-Object { $null -ne $_} | ForEach-Object { Invoke-BaselineRegistryAudit -BaselineItem $_ }
}